/* -*- mode: c -*- */

/* Copyright (C) 2004-2015 Alexander Chernov <cher@ejudge.ru> */

/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#include "ejudge/super_proto.h"

#include "ejudge/xalloc.h"

#include <stdio.h>

unsigned char const * const super_proto_error_messages[] =
{
  "no error",
  "error code 1",
  "not connected",
  "invalid file descriptors",
  "write to server failed",
  "invalid socket name",
  "system call failed",
  "connection refused",
  "read from server failed",
  "unexpected EOF from server",
  "protocol error",
  "userlist-server is down",
  "permission denied",
  "invalid contest",
  "IP-address is banned",
  "contest root_dir is not set",
  "file does not exist",
  "log file is redirected to /dev/null",
  "read error",
  "file format is invalid",
  "unexpected userlist-server error",
  "contest is already used",
  "another contest is edited in this session",
  "not implemented yet",
  "invalid parameter",
  "no contest is edited",
  "duplicated login name",
  "such problem already exists",
  "this problem is used as base problem",
  "parameter is out of range",
  "request disabled in slave mode",

  [SSERV_ERR_EMPTY_REPLY] = "Reply text is empty",
  [SSERV_ERR_INV_OPER] = "Invalid operation",
  [SSERV_ERR_INV_SID] = "Invalid session id",
  [SSERV_ERR_INV_CONTEST] = "Invalid contest id",
  [SSERV_ERR_PERM_DENIED] = "Permission denied",
  [SSERV_ERR_INTERNAL] = "Internal error",
  [SSERV_ERR_ALREADY_EDITED] = "Contest is already edited",
  [SSERV_ERR_NO_EDITED_CNTS] = "No contest is edited",
  [SSERV_ERR_INV_FIELD_ID] = "Invalid field ID",
  [SSERV_ERR_INV_VALUE] = "Invalid value",
  [SSERV_ERR_CONTEST_ALREADY_EXISTS] = "Contest with this ID already exists",
  [SSERV_ERR_CONTEST_ALREADY_EDITED] = "Contest is edited by another person",
  [SSERV_ERR_INV_LANG_ID] = "Invalid Lang ID",
  [SSERV_ERR_INV_PROB_ID] = "Invalid Prob ID",
  [SSERV_ERR_INV_PACKAGE] = "Invalid package",
  [SSERV_ERR_ITEM_EXISTS] = "Such item already exists",
  [SSERV_ERR_OPERATION_FAILED] = "System operation failed",
  [SSERV_ERR_INV_USER_ID] = "Invalid User ID",
  [SSERV_ERR_NO_CONNECTION] = "No connection to the database",
  [SSERV_ERR_DB_ERROR] = "Database error",
  [SSERV_ERR_UNSPEC_PASSWD1] = "Password 1 is not specified",
  [SSERV_ERR_UNSPEC_PASSWD2] = "Password 2 is not specified",
  [SSERV_ERR_INV_PASSWD1] = "Password 1 is invalid",
  [SSERV_ERR_INV_PASSWD2] = "Password 2 is invalid",
  [SSERV_ERR_PASSWDS_DIFFER] = "Passwords do not match each other",
  [SSERV_ERR_UNSPEC_LOGIN] = "Login is not specified",
  [SSERV_ERR_INV_GROUP_ID] = "Invalid group ID",
  [SSERV_ERR_INV_FIRST_SERIAL] = "Invalid first serial number",
  [SSERV_ERR_INV_LAST_SERIAL] = "Invalid last serial number",
  [SSERV_ERR_INV_RANGE] = "Invalid serial number range",
  [SSERV_ERR_INV_LOGIN_TEMPLATE] = "Invalid login template",
  [SSERV_ERR_INV_REG_PASSWORD_TEMPLATE] = "Invalid registration password template",
  [SSERV_ERR_INV_CNTS_PASSWORD_TEMPLATE] = "Invalid contest password template",
  [SSERV_ERR_INV_CNTS_NAME_TEMPLATE] = "Invalid name template",
  [SSERV_ERR_INV_CSV_FILE] = "Invalid CSV file",
  [SSERV_ERR_INV_CHARSET] = "Invalid charset",
  [SSERV_ERR_INV_SEPARATOR] = "Invalid field separator",
  [SSERV_ERR_DATA_READ_ONLY] = "Data is read-only",
  [SSERV_ERR_TOO_MANY_MEMBERS] = "Too many members",
  [SSERV_ERR_INV_SERIAL] = "Invalid member",
  [SSERV_ERR_INV_EMAIL] = "Invalid email",
  [SSERV_ERR_INV_GROUP_NAME] = "Invalid group name",
  [SSERV_ERR_INV_DESCRIPTION] = "Invalid description",
  [SSERV_ERR_GROUP_CREATION_FAILED] = "Group creation failed",
  [SSERV_ERR_INV_SERVE_CONFIG_PATH] = "Invalid serve.cfg configuration file",
  [SSERV_ERR_INV_VARIANT] = "Invalid variant",
  [SSERV_ERR_UNSUPPORTED_SETTINGS] = "Settings of this contest are incompatible with this feature",
  [SSERV_ERR_INV_CNTS_SETTINGS] = "Invalid contest settings",
  [SSERV_ERR_INV_TEST_NUM] = "Invalid test number",
  [SSERV_ERR_FS_ERROR] = "Filesystem error",
  [SSERV_ERR_INV_EXIT_CODE] = "Invalid exit code",
  [SSERV_ERR_INV_SYS_GROUP] = "Invalid system group",
  [SSERV_ERR_INV_SYS_MODE] = "Invalid system mode",
  [SSERV_ERR_INV_TESTINFO] = "Invalid test information",
  [SSERV_ERR_INV_PROB_XML] = "Invalid statement XML file",
  [SSERV_ERR_UNSPEC_PROB_PACKAGE] = "Problem package is unspecified",
  [SSERV_ERR_UNSPEC_PROB_NAME] = "Problem name is unspecified",
  [SSERV_ERR_INV_XHTML] = "Invalid XHTML",

  "unknown error",
};

unsigned char const *
super_proto_strerror(int n)
{
  if (n < 0) n = -n;
  if (n >= SSERV_ERR_LAST) {
    // this is error anyway, so leak some memory
    unsigned char buf[64];

    snprintf(buf, sizeof(buf), "unknown error %d", n);
    return xstrdup(buf);
  }
  return super_proto_error_messages[n];
}

const int super_proto_op_redirect[SSERV_CMD_LAST] =
{
  [SSERV_CMD_USER_FILTER_FIRST_PAGE_ACTION] = SSERV_CMD_USER_FILTER_CHANGE_ACTION,
  [SSERV_CMD_USER_FILTER_PREV_PAGE_ACTION] = SSERV_CMD_USER_FILTER_CHANGE_ACTION,
  [SSERV_CMD_USER_FILTER_NEXT_PAGE_ACTION] = SSERV_CMD_USER_FILTER_CHANGE_ACTION,
  [SSERV_CMD_USER_FILTER_LAST_PAGE_ACTION] = SSERV_CMD_USER_FILTER_CHANGE_ACTION,

  [SSERV_CMD_USER_BROWSE_UNMARK_ALL_ACTION] = SSERV_CMD_USER_BROWSE_MARK_ALL_ACTION,
  [SSERV_CMD_USER_BROWSE_TOGGLE_ALL_ACTION] = SSERV_CMD_USER_BROWSE_MARK_ALL_ACTION,

  [SSERV_CMD_USER_SAVE_AND_PREV_ACTION] = SSERV_CMD_USER_SAVE_ACTION,
  [SSERV_CMD_USER_SAVE_AND_NEXT_ACTION] = SSERV_CMD_USER_SAVE_ACTION,

  [SSERV_CMD_USER_CANCEL_AND_PREV_ACTION] = SSERV_CMD_USER_CANCEL_ACTION,
  [SSERV_CMD_USER_CANCEL_AND_NEXT_ACTION] = SSERV_CMD_USER_CANCEL_ACTION,

  [SSERV_CMD_USER_SEL_CLEAR_CNTS_PASSWD_PAGE] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_PAGE,
  [SSERV_CMD_USER_SEL_RANDOM_CNTS_PASSWD_PAGE] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_PAGE,
  [SSERV_CMD_USER_SEL_DELETE_REG_PAGE] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_PAGE,
  [SSERV_CMD_USER_SEL_CHANGE_REG_STATUS_PAGE] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_PAGE,
  [SSERV_CMD_USER_SEL_CHANGE_REG_FLAGS_PAGE] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_PAGE,
  [SSERV_CMD_USER_SEL_CREATE_REG_PAGE] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_PAGE,
  [SSERV_CMD_USER_SEL_CREATE_REG_AND_COPY_PAGE] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_PAGE,
  [SSERV_CMD_USER_SEL_CREATE_GROUP_MEMBER_PAGE] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_PAGE,
  [SSERV_CMD_USER_SEL_DELETE_GROUP_MEMBER_PAGE] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_PAGE,

  [SSERV_CMD_USER_SEL_CLEAR_CNTS_PASSWD_ACTION] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_ACTION,
  [SSERV_CMD_USER_SEL_RANDOM_CNTS_PASSWD_ACTION] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_ACTION,
  [SSERV_CMD_USER_SEL_DELETE_REG_ACTION] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_ACTION,
  [SSERV_CMD_USER_SEL_CHANGE_REG_STATUS_ACTION] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_ACTION,
  [SSERV_CMD_USER_SEL_CHANGE_REG_FLAGS_ACTION] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_ACTION,
  [SSERV_CMD_USER_SEL_CREATE_REG_ACTION] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_ACTION,
  [SSERV_CMD_USER_SEL_CREATE_REG_AND_COPY_ACTION] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_ACTION,
  [SSERV_CMD_USER_SEL_CREATE_GROUP_MEMBER_ACTION] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_ACTION,
  [SSERV_CMD_USER_SEL_DELETE_GROUP_MEMBER_ACTION] = SSERV_CMD_USER_SEL_RANDOM_PASSWD_ACTION,

  [SSERV_CMD_USER_SEL_VIEW_CNTS_PASSWD_PAGE] = SSERV_CMD_USER_SEL_VIEW_PASSWD_PAGE,
  [SSERV_CMD_USER_SEL_VIEW_CNTS_PASSWD_REDIRECT] = SSERV_CMD_USER_SEL_VIEW_PASSWD_REDIRECT,

  [SSERV_CMD_GROUP_FILTER_FIRST_PAGE_ACTION] = SSERV_CMD_GROUP_FILTER_CHANGE_ACTION,
  [SSERV_CMD_GROUP_FILTER_PREV_PAGE_ACTION] = SSERV_CMD_GROUP_FILTER_CHANGE_ACTION,
  [SSERV_CMD_GROUP_FILTER_NEXT_PAGE_ACTION] = SSERV_CMD_GROUP_FILTER_CHANGE_ACTION,
  [SSERV_CMD_GROUP_FILTER_LAST_PAGE_ACTION] = SSERV_CMD_GROUP_FILTER_CHANGE_ACTION,

  [SSERV_CMD_TESTS_TEST_MOVE_DOWN_ACTION] = SSERV_CMD_TESTS_TEST_MOVE_UP_ACTION,
  [SSERV_CMD_TESTS_SAVED_MOVE_UP_ACTION] = SSERV_CMD_TESTS_TEST_MOVE_UP_ACTION,
  [SSERV_CMD_TESTS_SAVED_MOVE_DOWN_ACTION] = SSERV_CMD_TESTS_TEST_MOVE_UP_ACTION,
  [SSERV_CMD_TESTS_SAVED_MOVE_TO_TEST_ACTION] = SSERV_CMD_TESTS_TEST_MOVE_TO_SAVED_ACTION,

  [SSERV_CMD_TESTS_STATEMENT_EDIT_3_ACTION] = SSERV_CMD_TESTS_STATEMENT_EDIT_ACTION,
  [SSERV_CMD_TESTS_STATEMENT_EDIT_4_ACTION] = SSERV_CMD_TESTS_STATEMENT_EDIT_ACTION,
  [SSERV_CMD_TESTS_STATEMENT_DELETE_SAMPLE_ACTION] = SSERV_CMD_TESTS_STATEMENT_EDIT_ACTION,

  [SSERV_CMD_TESTS_STATEMENT_EDIT_5_ACTION] = SSERV_CMD_TESTS_STATEMENT_EDIT_2_ACTION,

  [SSERV_CMD_TESTS_SOURCE_FOOTER_EDIT_PAGE] = SSERV_CMD_TESTS_SOURCE_HEADER_EDIT_PAGE,
  [SSERV_CMD_TESTS_SOURCE_FOOTER_EDIT_ACTION] = SSERV_CMD_TESTS_SOURCE_HEADER_EDIT_ACTION,
  [SSERV_CMD_TESTS_SOURCE_FOOTER_DELETE_ACTION] = SSERV_CMD_TESTS_SOURCE_HEADER_DELETE_ACTION,
  [SSERV_CMD_TESTS_SOLUTION_EDIT_PAGE] = SSERV_CMD_TESTS_SOURCE_HEADER_EDIT_PAGE,
  [SSERV_CMD_TESTS_SOLUTION_EDIT_ACTION] = SSERV_CMD_TESTS_SOURCE_HEADER_EDIT_ACTION,
  [SSERV_CMD_TESTS_SOLUTION_DELETE_ACTION] = SSERV_CMD_TESTS_SOURCE_HEADER_DELETE_ACTION,

  [SSERV_CMD_TESTS_STYLE_CHECKER_CREATE_PAGE] = SSERV_CMD_TESTS_CHECKER_CREATE_PAGE,
  [SSERV_CMD_TESTS_VALUER_CREATE_PAGE] = SSERV_CMD_TESTS_CHECKER_CREATE_PAGE,
  [SSERV_CMD_TESTS_INTERACTOR_CREATE_PAGE] = SSERV_CMD_TESTS_CHECKER_CREATE_PAGE,
  [SSERV_CMD_TESTS_TEST_CHECKER_CREATE_PAGE] = SSERV_CMD_TESTS_CHECKER_CREATE_PAGE,
  [SSERV_CMD_TESTS_INIT_CREATE_PAGE] = SSERV_CMD_TESTS_CHECKER_CREATE_PAGE,

  [SSERV_CMD_TESTS_STYLE_CHECKER_CREATE_ACTION] = SSERV_CMD_TESTS_CHECKER_CREATE_ACTION,
  [SSERV_CMD_TESTS_VALUER_CREATE_ACTION] = SSERV_CMD_TESTS_CHECKER_CREATE_ACTION,
  [SSERV_CMD_TESTS_INTERACTOR_CREATE_ACTION] = SSERV_CMD_TESTS_CHECKER_CREATE_ACTION,
  [SSERV_CMD_TESTS_TEST_CHECKER_CREATE_ACTION] = SSERV_CMD_TESTS_CHECKER_CREATE_ACTION,
  [SSERV_CMD_TESTS_INIT_CREATE_ACTION] = SSERV_CMD_TESTS_CHECKER_CREATE_ACTION,

  [SSERV_CMD_TESTS_STYLE_CHECKER_EDIT_PAGE] = SSERV_CMD_TESTS_CHECKER_EDIT_PAGE,
  [SSERV_CMD_TESTS_VALUER_EDIT_PAGE] = SSERV_CMD_TESTS_CHECKER_EDIT_PAGE,
  [SSERV_CMD_TESTS_INTERACTOR_EDIT_PAGE] = SSERV_CMD_TESTS_CHECKER_EDIT_PAGE,
  [SSERV_CMD_TESTS_TEST_CHECKER_EDIT_PAGE] = SSERV_CMD_TESTS_CHECKER_EDIT_PAGE,
  [SSERV_CMD_TESTS_INIT_EDIT_PAGE] = SSERV_CMD_TESTS_CHECKER_EDIT_PAGE,

  [SSERV_CMD_TESTS_STYLE_CHECKER_EDIT_ACTION] = SSERV_CMD_TESTS_CHECKER_EDIT_ACTION,
  [SSERV_CMD_TESTS_VALUER_EDIT_ACTION] = SSERV_CMD_TESTS_CHECKER_EDIT_ACTION,
  [SSERV_CMD_TESTS_INTERACTOR_EDIT_ACTION] = SSERV_CMD_TESTS_CHECKER_EDIT_ACTION,
  [SSERV_CMD_TESTS_TEST_CHECKER_EDIT_ACTION] = SSERV_CMD_TESTS_CHECKER_EDIT_ACTION,
  [SSERV_CMD_TESTS_INIT_EDIT_ACTION] = SSERV_CMD_TESTS_CHECKER_EDIT_ACTION,

  [SSERV_CMD_TESTS_STYLE_CHECKER_DELETE_PAGE] = SSERV_CMD_TESTS_CHECKER_DELETE_PAGE,
  [SSERV_CMD_TESTS_VALUER_DELETE_PAGE] = SSERV_CMD_TESTS_CHECKER_DELETE_PAGE,
  [SSERV_CMD_TESTS_INTERACTOR_DELETE_PAGE] = SSERV_CMD_TESTS_CHECKER_DELETE_PAGE,
  [SSERV_CMD_TESTS_TEST_CHECKER_DELETE_PAGE] = SSERV_CMD_TESTS_CHECKER_DELETE_PAGE,
  [SSERV_CMD_TESTS_INIT_DELETE_PAGE] = SSERV_CMD_TESTS_CHECKER_DELETE_PAGE,

  [SSERV_CMD_TESTS_STYLE_CHECKER_DELETE_ACTION] = SSERV_CMD_TESTS_CHECKER_DELETE_ACTION,
  [SSERV_CMD_TESTS_VALUER_DELETE_ACTION] = SSERV_CMD_TESTS_CHECKER_DELETE_ACTION,
  [SSERV_CMD_TESTS_INTERACTOR_DELETE_ACTION] = SSERV_CMD_TESTS_CHECKER_DELETE_ACTION,
  [SSERV_CMD_TESTS_TEST_CHECKER_DELETE_ACTION] = SSERV_CMD_TESTS_CHECKER_DELETE_ACTION,
  [SSERV_CMD_TESTS_INIT_DELETE_ACTION] = SSERV_CMD_TESTS_CHECKER_DELETE_ACTION,

  [SSERV_CMD_TESTS_TEST_INSERT_PAGE] = SSERV_CMD_TESTS_TEST_EDIT_PAGE,
  [SSERV_CMD_TESTS_TEST_INSERT_ACTION] = SSERV_CMD_TESTS_TEST_EDIT_ACTION,

  [SSERV_CMD_TESTS_CANCEL_2_ACTION] = SSERV_CMD_TESTS_CANCEL_ACTION,

  [SSERV_CMD_TESTS_CHECK_TESTS_PAGE] = SSERV_CMD_TESTS_MAKE,
  [SSERV_CMD_TESTS_GENERATE_ANSWERS_PAGE] = SSERV_CMD_TESTS_MAKE,
  [SSERV_CMD_TESTS_TEST_GENERATE_ACTION] = SSERV_CMD_TESTS_TEST_CHECK_ACTION,

  [SSERV_CMD_DOWNLOAD_CLEANUP_AND_CHECK_ACTION] = SSERV_CMD_DOWNLOAD_CLEANUP_ACTION,
};

const unsigned char * const super_proto_cmd_names[SSERV_CMD_LAST] =
{
  [SSERV_CMD_PASS_FD] = "PASS_FD",
  [SSERV_CMD_STOP] = "STOP",
  [SSERV_CMD_RESTART] = "RESTART",
  [SSERV_CMD_OPEN_CONTEST] = "OPEN_CONTEST",
  [SSERV_CMD_CLOSE_CONTEST] = "CLOSE_CONTEST",
  [SSERV_CMD_INVISIBLE_CONTEST] = "INVISIBLE_CONTEST",
  [SSERV_CMD_VISIBLE_CONTEST] = "VISIBLE_CONTEST",
  [SSERV_CMD_SHOW_HIDDEN] = "SHOW_HIDDEN",
  [SSERV_CMD_HIDE_HIDDEN] = "HIDE_HIDDEN",
  [SSERV_CMD_SHOW_CLOSED] = "SHOW_CLOSED",
  [SSERV_CMD_HIDE_CLOSED] = "HIDE_CLOSED",
  [SSERV_CMD_SHOW_UNMNG] = "SHOW_UNMNG",
  [SSERV_CMD_HIDE_UNMNG] = "HIDE_UNMNG",
  [SSERV_CMD_RUN_LOG_TRUNC] = "RUN_LOG_TRUNC",
  [SSERV_CMD_RUN_LOG_DEV_NULL] = "RUN_LOG_DEV_NULL",
  [SSERV_CMD_RUN_LOG_FILE] = "RUN_LOG_FILE",
  [SSERV_CMD_RUN_MNG_TERM] = "RUN_MNG_TERM",
  [SSERV_CMD_CONTEST_RESTART] = "CONTEST_RESTART",
  [SSERV_CMD_CLEAR_MESSAGES] = "CLEAR_MESSAGES",
  [SSERV_CMD_RUN_MNG_RESET_ERROR] = "RUN_MNG_RESET_ERROR",
  [SSERV_CMD_CNTS_BASIC_VIEW] = "CNTS_BASIC_VIEW",
  [SSERV_CMD_CNTS_ADVANCED_VIEW] = "CNTS_ADVANCED_VIEW",
  [SSERV_CMD_CNTS_SHOW_HTML_HEADERS] = "CNTS_SHOW_HTML_HEADERS",
  [SSERV_CMD_CNTS_HIDE_HTML_HEADERS] = "CNTS_HIDE_HTML_HEADERS",
  [SSERV_CMD_CNTS_SHOW_HTML_ATTRS] = "CNTS_SHOW_HTML_ATTRS",
  [SSERV_CMD_CNTS_HIDE_HTML_ATTRS] = "CNTS_HIDE_HTML_ATTRS",
  [SSERV_CMD_CNTS_FORGET] = "CNTS_FORGET",
  [SSERV_CMD_CNTS_SHOW_PATHS] = "CNTS_SHOW_PATHS",
  [SSERV_CMD_CNTS_HIDE_PATHS] = "CNTS_HIDE_PATHS",
  [SSERV_CMD_CNTS_SHOW_NOTIFICATIONS] = "CNTS_SHOW_NOTIFICATIONS",
  [SSERV_CMD_CNTS_HIDE_NOTIFICATIONS] = "CNTS_HIDE_NOTIFICATIONS",
  [SSERV_CMD_CNTS_SHOW_ACCESS_RULES] = "CNTS_SHOW_ACCESS_RULES",
  [SSERV_CMD_CNTS_HIDE_ACCESS_RULES] = "CNTS_HIDE_ACCESS_RULES",
  [SSERV_CMD_CNTS_SHOW_PERMISSIONS] = "CNTS_SHOW_PERMISSIONS",
  [SSERV_CMD_CNTS_HIDE_PERMISSIONS] = "CNTS_HIDE_PERMISSIONS",
  [SSERV_CMD_CNTS_SHOW_FORM_FIELDS] = "CNTS_SHOW_FORM_FIELDS",
  [SSERV_CMD_CNTS_HIDE_FORM_FIELDS] = "CNTS_HIDE_FORM_FIELDS",
  [SSERV_CMD_CNTS_CLEAR_NAME] = "CNTS_CLEAR_NAME",
  [SSERV_CMD_CNTS_CLEAR_NAME_EN] = "CNTS_CLEAR_NAME_EN",
  [SSERV_CMD_CNTS_CLEAR_MAIN_URL] = "CNTS_CLEAR_MAIN_URL",
  [SSERV_CMD_CNTS_CLEAR_KEYWORDS] = "CNTS_CLEAR_KEYWORDS",
  [SSERV_CMD_CNTS_CLEAR_USER_CONTEST] = "CNTS_CLEAR_USER_CONTEST",
  [SSERV_CMD_CNTS_CLEAR_DEFAULT_LOCALE] = "CNTS_CLEAR_DEFAULT_LOCALE",
  [SSERV_CMD_CNTS_CLEAR_DEADLINE] = "CNTS_CLEAR_DEADLINE",
  [SSERV_CMD_CNTS_CLEAR_SCHED_TIME] = "CNTS_CLEAR_SCHED_TIME",
  [SSERV_CMD_CNTS_CLEAR_OPEN_TIME] = "CNTS_CLEAR_OPEN_TIME",
  [SSERV_CMD_CNTS_CLEAR_CLOSE_TIME] = "CNTS_CLEAR_CLOSE_TIME",
  [SSERV_CMD_CNTS_CLEAR_USERS_HEADER] = "CNTS_CLEAR_USERS_HEADER",
  [SSERV_CMD_CNTS_CLEAR_USERS_FOOTER] = "CNTS_CLEAR_USERS_FOOTER",
  [SSERV_CMD_CNTS_CLEAR_REGISTER_HEADER] = "CNTS_CLEAR_REGISTER_HEADER",
  [SSERV_CMD_CNTS_CLEAR_REGISTER_FOOTER] = "CNTS_CLEAR_REGISTER_FOOTER",
  [SSERV_CMD_CNTS_CLEAR_TEAM_HEADER] = "CNTS_CLEAR_TEAM_HEADER",
  [SSERV_CMD_CNTS_CLEAR_TEAM_MENU_1] = "CNTS_CLEAR_TEAM_MENU_1",
  [SSERV_CMD_CNTS_CLEAR_TEAM_MENU_2] = "CNTS_CLEAR_TEAM_MENU_2",
  [SSERV_CMD_CNTS_CLEAR_TEAM_MENU_3] = "CNTS_CLEAR_TEAM_MENU_3",
  [SSERV_CMD_CNTS_CLEAR_TEAM_SEPARATOR] = "CNTS_CLEAR_TEAM_SEPARATOR",
  [SSERV_CMD_CNTS_CLEAR_TEAM_FOOTER] = "CNTS_CLEAR_TEAM_FOOTER",
  [SSERV_CMD_CNTS_CLEAR_PRIV_HEADER] = "CNTS_CLEAR_PRIV_HEADER",
  [SSERV_CMD_CNTS_CLEAR_PRIV_FOOTER] = "CNTS_CLEAR_PRIV_FOOTER",
  [SSERV_CMD_CNTS_CLEAR_COPYRIGHT] = "CNTS_CLEAR_COPYRIGHT",
  [SSERV_CMD_CNTS_CLEAR_WELCOME] = "CNTS_CLEAR_WELCOME",
  [SSERV_CMD_CNTS_CLEAR_REG_WELCOME] = "CNTS_CLEAR_REG_WELCOME",
  [SSERV_CMD_CNTS_CLEAR_USERS_HEAD_STYLE] = "CNTS_CLEAR_USERS_HEAD_STYLE",
  [SSERV_CMD_CNTS_CLEAR_USERS_PAR_STYLE] = "CNTS_CLEAR_USERS_PAR_STYLE",
  [SSERV_CMD_CNTS_CLEAR_USERS_TABLE_STYLE] = "CNTS_CLEAR_USERS_TABLE_STYLE",
  [SSERV_CMD_CNTS_CLEAR_USERS_VERB_STYLE] = "CNTS_CLEAR_USERS_VERB_STYLE",
  [SSERV_CMD_CNTS_CLEAR_USERS_TABLE_FORMAT] = "CNTS_CLEAR_USERS_TABLE_FORMAT",
  [SSERV_CMD_CNTS_CLEAR_USERS_TABLE_FORMAT_EN] = "CNTS_CLEAR_USERS_TABLE_FORMAT_EN",
  [SSERV_CMD_CNTS_CLEAR_USERS_TABLE_LEGEND] = "CNTS_CLEAR_USERS_TABLE_LEGEND",
  [SSERV_CMD_CNTS_CLEAR_USERS_TABLE_LEGEND_EN] = "CNTS_CLEAR_USERS_TABLE_LEGEND_EN",
  [SSERV_CMD_CNTS_CLEAR_REGISTER_HEAD_STYLE] = "CNTS_CLEAR_REGISTER_HEAD_STYLE",
  [SSERV_CMD_CNTS_CLEAR_REGISTER_PAR_STYLE] = "CNTS_CLEAR_REGISTER_PAR_STYLE",
  [SSERV_CMD_CNTS_CLEAR_REGISTER_TABLE_STYLE] = "CNTS_CLEAR_REGISTER_TABLE_STYLE",
  [SSERV_CMD_CNTS_CLEAR_REGISTER_NAME_COMMENT] = "CNTS_CLEAR_REGISTER_NAME_COMMENT",
  [SSERV_CMD_CNTS_CLEAR_ALLOWED_LANGUAGES] = "CNTS_CLEAR_ALLOWED_LANGUAGES",
  [SSERV_CMD_CNTS_CLEAR_ALLOWED_REGIONS] = "CNTS_CLEAR_ALLOWED_REGIONS",
  [SSERV_CMD_CNTS_CLEAR_CF_NOTIFY_EMAIL] = "CNTS_CLEAR_CF_NOTIFY_EMAIL",
  [SSERV_CMD_CNTS_CLEAR_CLAR_NOTIFY_EMAIL] = "CNTS_CLEAR_CLAR_NOTIFY_EMAIL",
  [SSERV_CMD_CNTS_CLEAR_DAILY_STAT_EMAIL] = "CNTS_CLEAR_DAILY_STAT_EMAIL",
  [SSERV_CMD_CNTS_CLEAR_TEAM_HEAD_STYLE] = "CNTS_CLEAR_TEAM_HEAD_STYLE",
  [SSERV_CMD_CNTS_CLEAR_TEAM_PAR_STYLE] = "CNTS_CLEAR_TEAM_PAR_STYLE",
  [SSERV_CMD_CNTS_CLEAR_REGISTER_EMAIL] = "CNTS_CLEAR_REGISTER_EMAIL",
  [SSERV_CMD_CNTS_CLEAR_REGISTER_URL] = "CNTS_CLEAR_REGISTER_URL",
  [SSERV_CMD_CNTS_CLEAR_LOGIN_TEMPLATE] = "CNTS_CLEAR_LOGIN_TEMPLATE",
  [SSERV_CMD_CNTS_CLEAR_LOGIN_TEMPLATE_OPTIONS] = "CNTS_CLEAR_LOGIN_TEMPLATE_OPTIONS",
  [SSERV_CMD_CNTS_CLEAR_REGISTER_EMAIL_FILE] = "CNTS_CLEAR_REGISTER_EMAIL_FILE",
  [SSERV_CMD_CNTS_CLEAR_TEAM_URL] = "CNTS_CLEAR_TEAM_URL",
  [SSERV_CMD_CNTS_CLEAR_STANDINGS_URL] = "CNTS_CLEAR_STANDINGS_URL",
  [SSERV_CMD_CNTS_CLEAR_PROBLEMS_URL] = "CNTS_CLEAR_PROBLEMS_URL",
  [SSERV_CMD_CNTS_CLEAR_LOGO_URL] = "CNTS_CLEAR_LOGO_URL",
  [SSERV_CMD_CNTS_CLEAR_CSS_URL] = "CNTS_CLEAR_CSS_URL",
  [SSERV_CMD_CNTS_CLEAR_REGISTER_SUBJECT] = "CNTS_CLEAR_REGISTER_SUBJECT",
  [SSERV_CMD_CNTS_CLEAR_REGISTER_SUBJECT_EN] = "CNTS_CLEAR_REGISTER_SUBJECT_EN",
  [SSERV_CMD_CNTS_CLEAR_ROOT_DIR] = "CNTS_CLEAR_ROOT_DIR",
  [SSERV_CMD_CNTS_CLEAR_CONF_DIR] = "CNTS_CLEAR_CONF_DIR",
  [SSERV_CMD_CNTS_CHANGE_NAME] = "CNTS_CHANGE_NAME",
  [SSERV_CMD_CNTS_CHANGE_NAME_EN] = "CNTS_CHANGE_NAME_EN",
  [SSERV_CMD_CNTS_CHANGE_MAIN_URL] = "CNTS_CHANGE_MAIN_URL",
  [SSERV_CMD_CNTS_CHANGE_KEYWORDS] = "CNTS_CHANGE_KEYWORDS",
  [SSERV_CMD_CNTS_CHANGE_USER_CONTEST] = "CNTS_CHANGE_USER_CONTEST",
  [SSERV_CMD_CNTS_CHANGE_DEFAULT_LOCALE] = "CNTS_CHANGE_DEFAULT_LOCALE",
  [SSERV_CMD_CNTS_CHANGE_AUTOREGISTER] = "CNTS_CHANGE_AUTOREGISTER",
  [SSERV_CMD_CNTS_CHANGE_TEAM_PASSWD] = "CNTS_CHANGE_TEAM_PASSWD",
  [SSERV_CMD_CNTS_CHANGE_SIMPLE_REGISTRATION] = "CNTS_CHANGE_SIMPLE_REGISTRATION",
  [SSERV_CMD_CNTS_CHANGE_ASSIGN_LOGINS] = "CNTS_CHANGE_ASSIGN_LOGINS",
  [SSERV_CMD_CNTS_CHANGE_FORCE_REGISTRATION] = "CNTS_CHANGE_FORCE_REGISTRATION",
  [SSERV_CMD_CNTS_CHANGE_DISABLE_NAME] = "CNTS_CHANGE_DISABLE_NAME",
  [SSERV_CMD_CNTS_CHANGE_ENABLE_PASSWORD_RECOVERY] = "CNTS_CHANGE_ENABLE_PASSWORD_RECOVERY",
  [SSERV_CMD_CNTS_CHANGE_EXAM_MODE] = "CNTS_CHANGE_EXAM_MODE",
  [SSERV_CMD_CNTS_CHANGE_DISABLE_PASSWORD_CHANGE] = "CNTS_CHANGE_DISABLE_PASSWORD_CHANGE",
  [SSERV_CMD_CNTS_CHANGE_DISABLE_LOCALE_CHANGE] = "CNTS_CHANGE_DISABLE_LOCALE_CHANGE",
  [SSERV_CMD_CNTS_CHANGE_PERSONAL] = "CNTS_CHANGE_PERSONAL",
  [SSERV_CMD_CNTS_CHANGE_ALLOW_REG_DATA_EDIT] = "CNTS_CHANGE_ALLOW_REG_DATA_EDIT",
  [SSERV_CMD_CNTS_CHANGE_SEND_PASSWD_EMAIL] = "CNTS_CHANGE_SEND_PASSWD_EMAIL",
  [SSERV_CMD_CNTS_CHANGE_MANAGED] = "CNTS_CHANGE_MANAGED",
  [SSERV_CMD_CNTS_CHANGE_RUN_MANAGED] = "CNTS_CHANGE_RUN_MANAGED",
  [SSERV_CMD_CNTS_CHANGE_OLD_RUN_MANAGED] = "CNTS_CHANGE_OLD_RUN_MANAGED",
  [SSERV_CMD_CNTS_CHANGE_CLEAN_USERS] = "CNTS_CHANGE_CLEAN_USERS",
  [SSERV_CMD_CNTS_CHANGE_CLOSED] = "CNTS_CHANGE_CLOSED",
  [SSERV_CMD_CNTS_CHANGE_INVISIBLE] = "CNTS_CHANGE_INVISIBLE",
  [SSERV_CMD_CNTS_CHANGE_MEMBER_DELETE] = "CNTS_CHANGE_MEMBER_DELETE",
  [SSERV_CMD_CNTS_CHANGE_DEADLINE] = "CNTS_CHANGE_DEADLINE",
  [SSERV_CMD_CNTS_CHANGE_SCHED_TIME] = "CNTS_CHANGE_SCHED_TIME",
  [SSERV_CMD_CNTS_CHANGE_OPEN_TIME] = "CNTS_CHANGE_OPEN_TIME",
  [SSERV_CMD_CNTS_CHANGE_CLOSE_TIME] = "CNTS_CHANGE_CLOSE_TIME",
  [SSERV_CMD_CNTS_CHANGE_USERS_HEADER] = "CNTS_CHANGE_USERS_HEADER",
  [SSERV_CMD_CNTS_CHANGE_USERS_FOOTER] = "CNTS_CHANGE_USERS_FOOTER",
  [SSERV_CMD_CNTS_CHANGE_REGISTER_HEADER] = "CNTS_CHANGE_REGISTER_HEADER",
  [SSERV_CMD_CNTS_CHANGE_REGISTER_FOOTER] = "CNTS_CHANGE_REGISTER_FOOTER",
  [SSERV_CMD_CNTS_CHANGE_TEAM_HEADER] = "CNTS_CHANGE_TEAM_HEADER",
  [SSERV_CMD_CNTS_CHANGE_TEAM_MENU_1] = "CNTS_CHANGE_TEAM_MENU_1",
  [SSERV_CMD_CNTS_CHANGE_TEAM_MENU_2] = "CNTS_CHANGE_TEAM_MENU_2",
  [SSERV_CMD_CNTS_CHANGE_TEAM_MENU_3] = "CNTS_CHANGE_TEAM_MENU_3",
  [SSERV_CMD_CNTS_CHANGE_TEAM_SEPARATOR] = "CNTS_CHANGE_TEAM_SEPARATOR",
  [SSERV_CMD_CNTS_CHANGE_TEAM_FOOTER] = "CNTS_CHANGE_TEAM_FOOTER",
  [SSERV_CMD_CNTS_CHANGE_PRIV_HEADER] = "CNTS_CHANGE_PRIV_HEADER",
  [SSERV_CMD_CNTS_CHANGE_PRIV_FOOTER] = "CNTS_CHANGE_PRIV_FOOTER",
  [SSERV_CMD_CNTS_CHANGE_COPYRIGHT] = "CNTS_CHANGE_COPYRIGHT",
  [SSERV_CMD_CNTS_CHANGE_WELCOME] = "CNTS_CHANGE_WELCOME",
  [SSERV_CMD_CNTS_CHANGE_REG_WELCOME] = "CNTS_CHANGE_REG_WELCOME",
  [SSERV_CMD_CNTS_CHANGE_USERS_HEAD_STYLE] = "CNTS_CHANGE_USERS_HEAD_STYLE",
  [SSERV_CMD_CNTS_CHANGE_USERS_PAR_STYLE] = "CNTS_CHANGE_USERS_PAR_STYLE",
  [SSERV_CMD_CNTS_CHANGE_USERS_TABLE_STYLE] = "CNTS_CHANGE_USERS_TABLE_STYLE",
  [SSERV_CMD_CNTS_CHANGE_USERS_VERB_STYLE] = "CNTS_CHANGE_USERS_VERB_STYLE",
  [SSERV_CMD_CNTS_CHANGE_USERS_TABLE_FORMAT] = "CNTS_CHANGE_USERS_TABLE_FORMAT",
  [SSERV_CMD_CNTS_CHANGE_USERS_TABLE_FORMAT_EN] = "CNTS_CHANGE_USERS_TABLE_FORMAT_EN",
  [SSERV_CMD_CNTS_CHANGE_USERS_TABLE_LEGEND] = "CNTS_CHANGE_USERS_TABLE_LEGEND",
  [SSERV_CMD_CNTS_CHANGE_USERS_TABLE_LEGEND_EN] = "CNTS_CHANGE_USERS_TABLE_LEGEND_EN",
  [SSERV_CMD_CNTS_CHANGE_REGISTER_HEAD_STYLE] = "CNTS_CHANGE_REGISTER_HEAD_STYLE",
  [SSERV_CMD_CNTS_CHANGE_REGISTER_PAR_STYLE] = "CNTS_CHANGE_REGISTER_PAR_STYLE",
  [SSERV_CMD_CNTS_CHANGE_REGISTER_TABLE_STYLE] = "CNTS_CHANGE_REGISTER_TABLE_STYLE",
  [SSERV_CMD_CNTS_CHANGE_REGISTER_NAME_COMMENT] = "CNTS_CHANGE_REGISTER_NAME_COMMENT",
  [SSERV_CMD_CNTS_CHANGE_ALLOWED_LANGUAGES] = "CNTS_CHANGE_ALLOWED_LANGUAGES",
  [SSERV_CMD_CNTS_CHANGE_ALLOWED_REGIONS] = "CNTS_CHANGE_ALLOWED_REGIONS",
  [SSERV_CMD_CNTS_CHANGE_CF_NOTIFY_EMAIL] = "CNTS_CHANGE_CF_NOTIFY_EMAIL",
  [SSERV_CMD_CNTS_CHANGE_CLAR_NOTIFY_EMAIL] = "CNTS_CHANGE_CLAR_NOTIFY_EMAIL",
  [SSERV_CMD_CNTS_CHANGE_DAILY_STAT_EMAIL] = "CNTS_CHANGE_DAILY_STAT_EMAIL",
  [SSERV_CMD_CNTS_CHANGE_TEAM_HEAD_STYLE] = "CNTS_CHANGE_TEAM_HEAD_STYLE",
  [SSERV_CMD_CNTS_CHANGE_TEAM_PAR_STYLE] = "CNTS_CHANGE_TEAM_PAR_STYLE",
  [SSERV_CMD_CNTS_CHANGE_REGISTER_EMAIL] = "CNTS_CHANGE_REGISTER_EMAIL",
  [SSERV_CMD_CNTS_CHANGE_REGISTER_URL] = "CNTS_CHANGE_REGISTER_URL",
  [SSERV_CMD_CNTS_CHANGE_LOGIN_TEMPLATE] = "CNTS_CHANGE_LOGIN_TEMPLATE",
  [SSERV_CMD_CNTS_CHANGE_LOGIN_TEMPLATE_OPTIONS] = "CNTS_CHANGE_LOGIN_TEMPLATE_OPTIONS",
  [SSERV_CMD_CNTS_CHANGE_REGISTER_EMAIL_FILE] = "CNTS_CHANGE_REGISTER_EMAIL_FILE",
  [SSERV_CMD_CNTS_CHANGE_TEAM_URL] = "CNTS_CHANGE_TEAM_URL",
  [SSERV_CMD_CNTS_CHANGE_STANDINGS_URL] = "CNTS_CHANGE_STANDINGS_URL",
  [SSERV_CMD_CNTS_CHANGE_PROBLEMS_URL] = "CNTS_CHANGE_PROBLEMS_URL",
  [SSERV_CMD_CNTS_CHANGE_LOGO_URL] = "CNTS_CHANGE_LOGO_URL",
  [SSERV_CMD_CNTS_CHANGE_CSS_URL] = "CNTS_CHANGE_CSS_URL",
  [SSERV_CMD_CNTS_CHANGE_REGISTER_SUBJECT] = "CNTS_CHANGE_REGISTER_SUBJECT",
  [SSERV_CMD_CNTS_CHANGE_REGISTER_SUBJECT_EN] = "CNTS_CHANGE_REGISTER_SUBJECT_EN",
  [SSERV_CMD_CNTS_CHANGE_ROOT_DIR] = "CNTS_CHANGE_ROOT_DIR",
  [SSERV_CMD_CNTS_CHANGE_CONF_DIR] = "CNTS_CHANGE_CONF_DIR",
  [SSERV_CMD_CNTS_CHANGE_DIR_MODE] = "CNTS_CHANGE_DIR_MODE",
  [SSERV_CMD_CNTS_CHANGE_DIR_GROUP] = "CNTS_CHANGE_DIR_GROUP",
  [SSERV_CMD_CNTS_CHANGE_FILE_MODE] = "CNTS_CHANGE_FILE_MODE",
  [SSERV_CMD_CNTS_CHANGE_FILE_GROUP] = "CNTS_CHANGE_FILE_GROUP",
  [SSERV_CMD_CNTS_CLEAR_DIR_MODE] = "CNTS_CLEAR_DIR_MODE",
  [SSERV_CMD_CNTS_CLEAR_DIR_GROUP] = "CNTS_CLEAR_DIR_GROUP",
  [SSERV_CMD_CNTS_CLEAR_FILE_MODE] = "CNTS_CLEAR_FILE_MODE",
  [SSERV_CMD_CNTS_CLEAR_FILE_GROUP] = "CNTS_CLEAR_FILE_GROUP",
  [SSERV_CMD_CNTS_DEFAULT_ACCESS] = "CNTS_DEFAULT_ACCESS",
  [SSERV_CMD_CNTS_ADD_RULE] = "CNTS_ADD_RULE",
  [SSERV_CMD_CNTS_CHANGE_RULE] = "CNTS_CHANGE_RULE",
  [SSERV_CMD_CNTS_DELETE_RULE] = "CNTS_DELETE_RULE",
  [SSERV_CMD_CNTS_UP_RULE] = "CNTS_UP_RULE",
  [SSERV_CMD_CNTS_DOWN_RULE] = "CNTS_DOWN_RULE",
  [SSERV_CMD_CNTS_COPY_ACCESS] = "CNTS_COPY_ACCESS",
  [SSERV_CMD_CNTS_DELETE_PERMISSION] = "CNTS_DELETE_PERMISSION",
  [SSERV_CMD_CNTS_ADD_PERMISSION] = "CNTS_ADD_PERMISSION",
  [SSERV_CMD_CNTS_SAVE_PERMISSIONS] = "CNTS_SAVE_PERMISSIONS",
  [SSERV_CMD_CNTS_SET_PREDEF_PERMISSIONS] = "CNTS_SET_PREDEF_PERMISSIONS",
  [SSERV_CMD_CNTS_SAVE_FORM_FIELDS] = "CNTS_SAVE_FORM_FIELDS",
  [SSERV_CMD_CNTS_SAVE_CONTESTANT_FIELDS] = "CNTS_SAVE_CONTESTANT_FIELDS",
  [SSERV_CMD_CNTS_SAVE_RESERVE_FIELDS] = "CNTS_SAVE_RESERVE_FIELDS",
  [SSERV_CMD_CNTS_SAVE_COACH_FIELDS] = "CNTS_SAVE_COACH_FIELDS",
  [SSERV_CMD_CNTS_SAVE_ADVISOR_FIELDS] = "CNTS_SAVE_ADVISOR_FIELDS",
  [SSERV_CMD_CNTS_SAVE_GUEST_FIELDS] = "CNTS_SAVE_GUEST_FIELDS",
  [SSERV_CMD_GLOB_SHOW_1] = "GLOB_SHOW_1",
  [SSERV_CMD_GLOB_HIDE_1] = "GLOB_HIDE_1",
  [SSERV_CMD_GLOB_SHOW_2] = "GLOB_SHOW_2",
  [SSERV_CMD_GLOB_HIDE_2] = "GLOB_HIDE_2",
  [SSERV_CMD_GLOB_SHOW_3] = "GLOB_SHOW_3",
  [SSERV_CMD_GLOB_HIDE_3] = "GLOB_HIDE_3",
  [SSERV_CMD_GLOB_SHOW_4] = "GLOB_SHOW_4",
  [SSERV_CMD_GLOB_HIDE_4] = "GLOB_HIDE_4",
  [SSERV_CMD_GLOB_SHOW_5] = "GLOB_SHOW_5",
  [SSERV_CMD_GLOB_HIDE_5] = "GLOB_HIDE_5",
  [SSERV_CMD_GLOB_SHOW_6] = "GLOB_SHOW_6",
  [SSERV_CMD_GLOB_HIDE_6] = "GLOB_HIDE_6",
  [SSERV_CMD_GLOB_SHOW_7] = "GLOB_SHOW_7",
  [SSERV_CMD_GLOB_HIDE_7] = "GLOB_HIDE_7",
  [SSERV_CMD_LANG_SHOW_DETAILS] = "LANG_SHOW_DETAILS",
  [SSERV_CMD_LANG_HIDE_DETAILS] = "LANG_HIDE_DETAILS",
  [SSERV_CMD_LANG_DEACTIVATE] = "LANG_DEACTIVATE",
  [SSERV_CMD_LANG_ACTIVATE] = "LANG_ACTIVATE",
  [SSERV_CMD_PROB_ADD_ABSTRACT] = "PROB_ADD_ABSTRACT",
  [SSERV_CMD_PROB_ADD] = "PROB_ADD",
  [SSERV_CMD_PROB_SHOW_DETAILS] = "PROB_SHOW_DETAILS",
  [SSERV_CMD_PROB_HIDE_DETAILS] = "PROB_HIDE_DETAILS",
  [SSERV_CMD_PROB_SHOW_ADVANCED] = "PROB_SHOW_ADVANCED",
  [SSERV_CMD_PROB_HIDE_ADVANCED] = "PROB_HIDE_ADVANCED",
  [SSERV_CMD_GLOB_CHANGE_DURATION] = "GLOB_CHANGE_DURATION",
  [SSERV_CMD_GLOB_UNLIMITED_DURATION] = "GLOB_UNLIMITED_DURATION",
  [SSERV_CMD_GLOB_CHANGE_TYPE] = "GLOB_CHANGE_TYPE",
  [SSERV_CMD_GLOB_CHANGE_FOG_TIME] = "GLOB_CHANGE_FOG_TIME",
  [SSERV_CMD_GLOB_CHANGE_UNFOG_TIME] = "GLOB_CHANGE_UNFOG_TIME",
  [SSERV_CMD_GLOB_DISABLE_FOG] = "GLOB_DISABLE_FOG",
  [SSERV_CMD_GLOB_CHANGE_STAND_LOCALE] = "GLOB_CHANGE_STAND_LOCALE",
  [SSERV_CMD_GLOB_CHANGE_CHECKER_LOCALE] = "GLOB_CHANGE_CHECKER_LOCALE",
  [SSERV_CMD_GLOB_CLEAR_CHECKER_LOCALE] = "GLOB_CLEAR_CHECKER_LOCALE",
  [SSERV_CMD_GLOB_CHANGE_TOKENS] = "GLOB_CHANGE_TOKENS",
  [SSERV_CMD_GLOB_CLEAR_TOKENS] = "GLOB_CLEAR_TOKENS",
  [SSERV_CMD_GLOB_CHANGE_SRC_VIEW] = "GLOB_CHANGE_SRC_VIEW",
  [SSERV_CMD_GLOB_CHANGE_REP_VIEW] = "GLOB_CHANGE_REP_VIEW",
  [SSERV_CMD_GLOB_CHANGE_CE_VIEW] = "GLOB_CHANGE_CE_VIEW",
  [SSERV_CMD_GLOB_CHANGE_JUDGE_REPORT] = "GLOB_CHANGE_JUDGE_REPORT",
  [SSERV_CMD_GLOB_CHANGE_DISABLE_CLARS] = "GLOB_CHANGE_DISABLE_CLARS",
  [SSERV_CMD_GLOB_CHANGE_DISABLE_TEAM_CLARS] = "GLOB_CHANGE_DISABLE_TEAM_CLARS",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_EOLN_SELECT] = "GLOB_CHANGE_ENABLE_EOLN_SELECT",
  [SSERV_CMD_GLOB_CHANGE_DISABLE_SUBMIT_AFTER_OK] = "GLOB_CHANGE_DISABLE_SUBMIT_AFTER_OK",
  [SSERV_CMD_GLOB_CHANGE_IGNORE_COMPILE_ERRORS] = "GLOB_CHANGE_IGNORE_COMPILE_ERRORS",
  [SSERV_CMD_GLOB_CHANGE_DISABLE_FAILED_TEST_VIEW] = "GLOB_CHANGE_DISABLE_FAILED_TEST_VIEW",
  [SSERV_CMD_GLOB_CHANGE_IGNORE_DUPLICATED_RUNS] = "GLOB_CHANGE_IGNORE_DUPLICATED_RUNS",
  [SSERV_CMD_GLOB_CHANGE_REPORT_ERROR_CODE] = "GLOB_CHANGE_REPORT_ERROR_CODE",
  [SSERV_CMD_GLOB_CHANGE_SHOW_DEADLINE] = "GLOB_CHANGE_SHOW_DEADLINE",
  [SSERV_CMD_GLOB_CHANGE_SHOW_SHA1] = "GLOB_CHANGE_SHOW_SHA1",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_PRINTING] = "GLOB_CHANGE_ENABLE_PRINTING",
  [SSERV_CMD_GLOB_CHANGE_DISABLE_BANNER_PAGE] = "GLOB_CHANGE_DISABLE_BANNER_PAGE",
  [SSERV_CMD_GLOB_CHANGE_PRINTOUT_USES_LOGIN] = "GLOB_CHANGE_PRINTOUT_USES_LOGIN",
  [SSERV_CMD_GLOB_CHANGE_PRUNE_EMPTY_USERS] = "GLOB_CHANGE_PRUNE_EMPTY_USERS",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_FULL_ARCHIVE] = "GLOB_CHANGE_ENABLE_FULL_ARCHIVE",
  [SSERV_CMD_GLOB_CHANGE_ADVANCED_LAYOUT] = "GLOB_CHANGE_ADVANCED_LAYOUT",
  [SSERV_CMD_GLOB_CHANGE_UUID_RUN_STORE] = "GLOB_CHANGE_UUID_RUN_STORE",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_32BIT_CHECKERS] = "GLOB_CHANGE_ENABLE_32BIT_CHECKERS",
  [SSERV_CMD_GLOB_CHANGE_IGNORE_BOM] = "GLOB_CHANGE_IGNORE_BOM",
  [SSERV_CMD_GLOB_CHANGE_DISABLE_USER_DATABASE] = "GLOB_CHANGE_DISABLE_USER_DATABASE",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_MAX_STACK_SIZE] = "GLOB_CHANGE_ENABLE_MAX_STACK_SIZE",
  [SSERV_CMD_GLOB_CHANGE_DISABLE_AUTO_REFRESH] = "GLOB_CHANGE_DISABLE_AUTO_REFRESH",
  [SSERV_CMD_GLOB_CHANGE_ALWAYS_SHOW_PROBLEMS] = "GLOB_CHANGE_ALWAYS_SHOW_PROBLEMS",
  [SSERV_CMD_GLOB_CHANGE_DISABLE_USER_STANDINGS] = "GLOB_CHANGE_DISABLE_USER_STANDINGS",
  [SSERV_CMD_GLOB_CHANGE_DISABLE_LANGUAGE] = "GLOB_CHANGE_DISABLE_LANGUAGE",
  [SSERV_CMD_GLOB_CHANGE_PROBLEM_NAVIGATION] = "GLOB_CHANGE_PROBLEM_NAVIGATION",
  [SSERV_CMD_GLOB_CHANGE_VERTICAL_NAVIGATION] = "GLOB_CHANGE_VERTICAL_NAVIGATION",
  [SSERV_CMD_GLOB_CHANGE_DISABLE_VIRTUAL_START] = "GLOB_CHANGE_DISABLE_VIRTUAL_START",
  [SSERV_CMD_GLOB_CHANGE_DISABLE_VIRTUAL_AUTO_JUDGE] = "GLOB_CHANGE_DISABLE_VIRTUAL_AUTO_JUDGE",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_AUTO_PRINT_PROTOCOL] = "GLOB_CHANGE_ENABLE_AUTO_PRINT_PROTOCOL",
  [SSERV_CMD_GLOB_CHANGE_NOTIFY_CLAR_REPLY] = "GLOB_CHANGE_NOTIFY_CLAR_REPLY",
  [SSERV_CMD_GLOB_CHANGE_NOTIFY_STATUS_CHANGE] = "GLOB_CHANGE_NOTIFY_STATUS_CHANGE",
  [SSERV_CMD_GLOB_CHANGE_TEST_DIR] = "GLOB_CHANGE_TEST_DIR",
  [SSERV_CMD_GLOB_CLEAR_TEST_DIR] = "GLOB_CLEAR_TEST_DIR",
  [SSERV_CMD_GLOB_CHANGE_CORR_DIR] = "GLOB_CHANGE_CORR_DIR",
  [SSERV_CMD_GLOB_CLEAR_CORR_DIR] = "GLOB_CLEAR_CORR_DIR",
  [SSERV_CMD_GLOB_CHANGE_INFO_DIR] = "GLOB_CHANGE_INFO_DIR",
  [SSERV_CMD_GLOB_CLEAR_INFO_DIR] = "GLOB_CLEAR_INFO_DIR",
  [SSERV_CMD_GLOB_CHANGE_TGZ_DIR] = "GLOB_CHANGE_TGZ_DIR",
  [SSERV_CMD_GLOB_CLEAR_TGZ_DIR] = "GLOB_CLEAR_TGZ_DIR",
  [SSERV_CMD_GLOB_CHANGE_CHECKER_DIR] = "GLOB_CHANGE_CHECKER_DIR",
  [SSERV_CMD_GLOB_CLEAR_CHECKER_DIR] = "GLOB_CLEAR_CHECKER_DIR",
  [SSERV_CMD_GLOB_CHANGE_STATEMENT_DIR] = "GLOB_CHANGE_STATEMENT_DIR",
  [SSERV_CMD_GLOB_CLEAR_STATEMENT_DIR] = "GLOB_CLEAR_STATEMENT_DIR",
  [SSERV_CMD_GLOB_CHANGE_PLUGIN_DIR] = "GLOB_CHANGE_PLUGIN_DIR",
  [SSERV_CMD_GLOB_CLEAR_PLUGIN_DIR] = "GLOB_CLEAR_PLUGIN_DIR",
  [SSERV_CMD_GLOB_CHANGE_DESCRIPTION_FILE] = "GLOB_CHANGE_DESCRIPTION_FILE",
  [SSERV_CMD_GLOB_CLEAR_DESCRIPTION_FILE] = "GLOB_CLEAR_DESCRIPTION_FILE",
  [SSERV_CMD_GLOB_CHANGE_CONTEST_START_CMD] = "GLOB_CHANGE_CONTEST_START_CMD",
  [SSERV_CMD_GLOB_CLEAR_CONTEST_START_CMD] = "GLOB_CLEAR_CONTEST_START_CMD",
  [SSERV_CMD_GLOB_CHANGE_CONTEST_STOP_CMD] = "GLOB_CHANGE_CONTEST_STOP_CMD",
  [SSERV_CMD_GLOB_CLEAR_CONTEST_STOP_CMD] = "GLOB_CLEAR_CONTEST_STOP_CMD",
  [SSERV_CMD_GLOB_CHANGE_MAX_RUN_SIZE] = "GLOB_CHANGE_MAX_RUN_SIZE",
  [SSERV_CMD_GLOB_CHANGE_MAX_RUN_TOTAL] = "GLOB_CHANGE_MAX_RUN_TOTAL",
  [SSERV_CMD_GLOB_CHANGE_MAX_RUN_NUM] = "GLOB_CHANGE_MAX_RUN_NUM",
  [SSERV_CMD_GLOB_CHANGE_MAX_CLAR_SIZE] = "GLOB_CHANGE_MAX_CLAR_SIZE",
  [SSERV_CMD_GLOB_CHANGE_MAX_CLAR_TOTAL] = "GLOB_CHANGE_MAX_CLAR_TOTAL",
  [SSERV_CMD_GLOB_CHANGE_MAX_CLAR_NUM] = "GLOB_CHANGE_MAX_CLAR_NUM",
  [SSERV_CMD_GLOB_CHANGE_TEAM_PAGE_QUOTA] = "GLOB_CHANGE_TEAM_PAGE_QUOTA",
  [SSERV_CMD_GLOB_CHANGE_TEAM_INFO_URL] = "GLOB_CHANGE_TEAM_INFO_URL",
  [SSERV_CMD_GLOB_CLEAR_TEAM_INFO_URL] = "GLOB_CLEAR_TEAM_INFO_URL",
  [SSERV_CMD_GLOB_CHANGE_PROB_INFO_URL] = "GLOB_CHANGE_PROB_INFO_URL",
  [SSERV_CMD_GLOB_CLEAR_PROB_INFO_URL] = "GLOB_CLEAR_PROB_INFO_URL",
  [SSERV_CMD_GLOB_CHANGE_STAND_FILE_NAME] = "GLOB_CHANGE_STAND_FILE_NAME",
  [SSERV_CMD_GLOB_CLEAR_STAND_FILE_NAME] = "GLOB_CLEAR_STAND_FILE_NAME",
  [SSERV_CMD_GLOB_CHANGE_USERS_ON_PAGE] = "GLOB_CHANGE_USERS_ON_PAGE",
  [SSERV_CMD_GLOB_CHANGE_STAND_HEADER_FILE] = "GLOB_CHANGE_STAND_HEADER_FILE",
  [SSERV_CMD_GLOB_CLEAR_STAND_HEADER_FILE] = "GLOB_CLEAR_STAND_HEADER_FILE",
  [SSERV_CMD_GLOB_CHANGE_STAND_FOOTER_FILE] = "GLOB_CHANGE_STAND_FOOTER_FILE",
  [SSERV_CMD_GLOB_CLEAR_STAND_FOOTER_FILE] = "GLOB_CLEAR_STAND_FOOTER_FILE",
  [SSERV_CMD_GLOB_CHANGE_STAND_SYMLINK_DIR] = "GLOB_CHANGE_STAND_SYMLINK_DIR",
  [SSERV_CMD_GLOB_CLEAR_STAND_SYMLINK_DIR] = "GLOB_CLEAR_STAND_SYMLINK_DIR",
  [SSERV_CMD_GLOB_CHANGE_STAND_IGNORE_AFTER] = "GLOB_CHANGE_STAND_IGNORE_AFTER",
  [SSERV_CMD_GLOB_CLEAR_STAND_IGNORE_AFTER] = "GLOB_CLEAR_STAND_IGNORE_AFTER",
  [SSERV_CMD_GLOB_CHANGE_APPEAL_DEADLINE] = "GLOB_CHANGE_APPEAL_DEADLINE",
  [SSERV_CMD_GLOB_CLEAR_APPEAL_DEADLINE] = "GLOB_CLEAR_APPEAL_DEADLINE",
  [SSERV_CMD_GLOB_CHANGE_CONTEST_FINISH_TIME] = "GLOB_CHANGE_CONTEST_FINISH_TIME",
  [SSERV_CMD_GLOB_CLEAR_CONTEST_FINISH_TIME] = "GLOB_CLEAR_CONTEST_FINISH_TIME",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_STAND2] = "GLOB_CHANGE_ENABLE_STAND2",
  [SSERV_CMD_GLOB_CHANGE_STAND2_FILE_NAME] = "GLOB_CHANGE_STAND2_FILE_NAME",
  [SSERV_CMD_GLOB_CLEAR_STAND2_FILE_NAME] = "GLOB_CLEAR_STAND2_FILE_NAME",
  [SSERV_CMD_GLOB_CHANGE_STAND2_HEADER_FILE] = "GLOB_CHANGE_STAND2_HEADER_FILE",
  [SSERV_CMD_GLOB_CLEAR_STAND2_HEADER_FILE] = "GLOB_CLEAR_STAND2_HEADER_FILE",
  [SSERV_CMD_GLOB_CHANGE_STAND2_FOOTER_FILE] = "GLOB_CHANGE_STAND2_FOOTER_FILE",
  [SSERV_CMD_GLOB_CLEAR_STAND2_FOOTER_FILE] = "GLOB_CLEAR_STAND2_FOOTER_FILE",
  [SSERV_CMD_GLOB_CHANGE_STAND2_SYMLINK_DIR] = "GLOB_CHANGE_STAND2_SYMLINK_DIR",
  [SSERV_CMD_GLOB_CLEAR_STAND2_SYMLINK_DIR] = "GLOB_CLEAR_STAND2_SYMLINK_DIR",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_PLOG] = "GLOB_CHANGE_ENABLE_PLOG",
  [SSERV_CMD_GLOB_CHANGE_PLOG_FILE_NAME] = "GLOB_CHANGE_PLOG_FILE_NAME",
  [SSERV_CMD_GLOB_CLEAR_PLOG_FILE_NAME] = "GLOB_CLEAR_PLOG_FILE_NAME",
  [SSERV_CMD_GLOB_CHANGE_PLOG_HEADER_FILE] = "GLOB_CHANGE_PLOG_HEADER_FILE",
  [SSERV_CMD_GLOB_CLEAR_PLOG_HEADER_FILE] = "GLOB_CLEAR_PLOG_HEADER_FILE",
  [SSERV_CMD_GLOB_CHANGE_PLOG_FOOTER_FILE] = "GLOB_CHANGE_PLOG_FOOTER_FILE",
  [SSERV_CMD_GLOB_CLEAR_PLOG_FOOTER_FILE] = "GLOB_CLEAR_PLOG_FOOTER_FILE",
  [SSERV_CMD_GLOB_CHANGE_PLOG_SYMLINK_DIR] = "GLOB_CHANGE_PLOG_SYMLINK_DIR",
  [SSERV_CMD_GLOB_CLEAR_PLOG_SYMLINK_DIR] = "GLOB_CLEAR_PLOG_SYMLINK_DIR",
  [SSERV_CMD_GLOB_CHANGE_PLOG_UPDATE_TIME] = "GLOB_CHANGE_PLOG_UPDATE_TIME",
  [SSERV_CMD_GLOB_CHANGE_EXTERNAL_XML_UPDATE_TIME] = "GLOB_CHANGE_EXTERNAL_XML_UPDATE_TIME",
  [SSERV_CMD_GLOB_CHANGE_INTERNAL_XML_UPDATE_TIME] = "GLOB_CHANGE_INTERNAL_XML_UPDATE_TIME",
  [SSERV_CMD_GLOB_CHANGE_STAND_FANCY_STYLE] = "GLOB_CHANGE_STAND_FANCY_STYLE",
  [SSERV_CMD_GLOB_CHANGE_STAND_TABLE_ATTR] = "GLOB_CHANGE_STAND_TABLE_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_TABLE_ATTR] = "GLOB_CLEAR_STAND_TABLE_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_PLACE_ATTR] = "GLOB_CHANGE_STAND_PLACE_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_PLACE_ATTR] = "GLOB_CLEAR_STAND_PLACE_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_TEAM_ATTR] = "GLOB_CHANGE_STAND_TEAM_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_TEAM_ATTR] = "GLOB_CLEAR_STAND_TEAM_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_PROB_ATTR] = "GLOB_CHANGE_STAND_PROB_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_PROB_ATTR] = "GLOB_CLEAR_STAND_PROB_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_SOLVED_ATTR] = "GLOB_CHANGE_STAND_SOLVED_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_SOLVED_ATTR] = "GLOB_CLEAR_STAND_SOLVED_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_SCORE_ATTR] = "GLOB_CHANGE_STAND_SCORE_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_SCORE_ATTR] = "GLOB_CLEAR_STAND_SCORE_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_PENALTY_ATTR] = "GLOB_CHANGE_STAND_PENALTY_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_PENALTY_ATTR] = "GLOB_CLEAR_STAND_PENALTY_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_USE_LOGIN] = "GLOB_CHANGE_STAND_USE_LOGIN",
  [SSERV_CMD_GLOB_CHANGE_STAND_SHOW_OK_TIME] = "GLOB_CHANGE_STAND_SHOW_OK_TIME",
  [SSERV_CMD_GLOB_CHANGE_STAND_SHOW_ATT_NUM] = "GLOB_CHANGE_STAND_SHOW_ATT_NUM",
  [SSERV_CMD_GLOB_CHANGE_STAND_SORT_BY_SOLVED] = "GLOB_CHANGE_STAND_SORT_BY_SOLVED",
  [SSERV_CMD_GLOB_CHANGE_IGNORE_SUCCESS_TIME] = "GLOB_CHANGE_IGNORE_SUCCESS_TIME",
  [SSERV_CMD_GLOB_CHANGE_STAND_COLLATE_NAME] = "GLOB_CHANGE_STAND_COLLATE_NAME",
  [SSERV_CMD_GLOB_CHANGE_STAND_ENABLE_PENALTY] = "GLOB_CHANGE_STAND_ENABLE_PENALTY",
  [SSERV_CMD_GLOB_CHANGE_STAND_TIME_ATTR] = "GLOB_CHANGE_STAND_TIME_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_TIME_ATTR] = "GLOB_CLEAR_STAND_TIME_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_SUCCESS_ATTR] = "GLOB_CHANGE_STAND_SUCCESS_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_SUCCESS_ATTR] = "GLOB_CLEAR_STAND_SUCCESS_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_FAIL_ATTR] = "GLOB_CHANGE_STAND_FAIL_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_FAIL_ATTR] = "GLOB_CLEAR_STAND_FAIL_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_TRANS_ATTR] = "GLOB_CHANGE_STAND_TRANS_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_TRANS_ATTR] = "GLOB_CLEAR_STAND_TRANS_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_DISQ_ATTR] = "GLOB_CHANGE_STAND_DISQ_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_DISQ_ATTR] = "GLOB_CLEAR_STAND_DISQ_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_SELF_ROW_ATTR] = "GLOB_CHANGE_STAND_SELF_ROW_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_SELF_ROW_ATTR] = "GLOB_CLEAR_STAND_SELF_ROW_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_V_ROW_ATTR] = "GLOB_CHANGE_STAND_V_ROW_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_V_ROW_ATTR] = "GLOB_CLEAR_STAND_V_ROW_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_R_ROW_ATTR] = "GLOB_CHANGE_STAND_R_ROW_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_R_ROW_ATTR] = "GLOB_CLEAR_STAND_R_ROW_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_U_ROW_ATTR] = "GLOB_CHANGE_STAND_U_ROW_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_U_ROW_ATTR] = "GLOB_CLEAR_STAND_U_ROW_ATTR",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_EXTRA_COL] = "GLOB_CHANGE_ENABLE_EXTRA_COL",
  [SSERV_CMD_GLOB_CHANGE_STAND_EXTRA_FORMAT] = "GLOB_CHANGE_STAND_EXTRA_FORMAT",
  [SSERV_CMD_GLOB_CLEAR_STAND_EXTRA_FORMAT] = "GLOB_CLEAR_STAND_EXTRA_FORMAT",
  [SSERV_CMD_GLOB_CHANGE_STAND_EXTRA_LEGEND] = "GLOB_CHANGE_STAND_EXTRA_LEGEND",
  [SSERV_CMD_GLOB_CLEAR_STAND_EXTRA_LEGEND] = "GLOB_CLEAR_STAND_EXTRA_LEGEND",
  [SSERV_CMD_GLOB_CHANGE_STAND_EXTRA_ATTR] = "GLOB_CHANGE_STAND_EXTRA_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_EXTRA_ATTR] = "GLOB_CLEAR_STAND_EXTRA_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_SHOW_WARN_NUMBER] = "GLOB_CHANGE_STAND_SHOW_WARN_NUMBER",
  [SSERV_CMD_GLOB_CHANGE_STAND_WARN_NUMBER_ATTR] = "GLOB_CHANGE_STAND_WARN_NUMBER_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_WARN_NUMBER_ATTR] = "GLOB_CLEAR_STAND_WARN_NUMBER_ATTR",
  [SSERV_CMD_GLOB_CHANGE_SLEEP_TIME] = "GLOB_CHANGE_SLEEP_TIME",
  [SSERV_CMD_GLOB_CHANGE_SERVE_SLEEP_TIME] = "GLOB_CHANGE_SERVE_SLEEP_TIME",
  [SSERV_CMD_GLOB_CHANGE_AUTOUPDATE_STANDINGS] = "GLOB_CHANGE_AUTOUPDATE_STANDINGS",
  [SSERV_CMD_GLOB_CHANGE_USE_AC_NOT_OK] = "GLOB_CHANGE_USE_AC_NOT_OK",
  [SSERV_CMD_GLOB_CHANGE_ROUNDING_MODE] = "GLOB_CHANGE_ROUNDING_MODE",
  [SSERV_CMD_GLOB_CHANGE_MAX_FILE_LENGTH] = "GLOB_CHANGE_MAX_FILE_LENGTH",
  [SSERV_CMD_GLOB_CHANGE_MAX_LINE_LENGTH] = "GLOB_CHANGE_MAX_LINE_LENGTH",
  [SSERV_CMD_GLOB_CHANGE_INACTIVITY_TIMEOUT] = "GLOB_CHANGE_INACTIVITY_TIMEOUT",
  [SSERV_CMD_GLOB_CHANGE_DISABLE_AUTO_TESTING] = "GLOB_CHANGE_DISABLE_AUTO_TESTING",
  [SSERV_CMD_GLOB_CHANGE_DISABLE_TESTING] = "GLOB_CHANGE_DISABLE_TESTING",
  [SSERV_CMD_GLOB_CHANGE_CR_SERIALIZATION_KEY] = "GLOB_CHANGE_CR_SERIALIZATION_KEY",
  [SSERV_CMD_GLOB_CHANGE_SHOW_ASTR_TIME] = "GLOB_CHANGE_SHOW_ASTR_TIME",
  [SSERV_CMD_GLOB_CHANGE_MEMOIZE_USER_RESULTS] = "GLOB_CHANGE_MEMOIZE_USER_RESULTS",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_CONTINUE] = "GLOB_CHANGE_ENABLE_CONTINUE",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_REPORT_UPLOAD] = "GLOB_CHANGE_ENABLE_REPORT_UPLOAD",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_RUNLOG_MERGE] = "GLOB_CHANGE_ENABLE_RUNLOG_MERGE",
  [SSERV_CMD_GLOB_CHANGE_USE_COMPILATION_SERVER] = "GLOB_CHANGE_USE_COMPILATION_SERVER",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_WIN32_LANGUAGES] = "GLOB_CHANGE_ENABLE_WIN32_LANGUAGES",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_L10N] = "GLOB_CHANGE_ENABLE_L10N",
  [SSERV_CMD_GLOB_CHANGE_CHARSET] = "GLOB_CHANGE_CHARSET",
  [SSERV_CMD_GLOB_CLEAR_CHARSET] = "GLOB_CLEAR_CHARSET",
  [SSERV_CMD_GLOB_CHANGE_STANDINGS_CHARSET] = "GLOB_CHANGE_STANDINGS_CHARSET",
  [SSERV_CMD_GLOB_CLEAR_STANDINGS_CHARSET] = "GLOB_CLEAR_STANDINGS_CHARSET",
  [SSERV_CMD_GLOB_CHANGE_STAND2_CHARSET] = "GLOB_CHANGE_STAND2_CHARSET",
  [SSERV_CMD_GLOB_CLEAR_STAND2_CHARSET] = "GLOB_CLEAR_STAND2_CHARSET",
  [SSERV_CMD_GLOB_CHANGE_PLOG_CHARSET] = "GLOB_CHANGE_PLOG_CHARSET",
  [SSERV_CMD_GLOB_CLEAR_PLOG_CHARSET] = "GLOB_CLEAR_PLOG_CHARSET",
  [SSERV_CMD_GLOB_CHANGE_TEAM_DOWNLOAD_TIME] = "GLOB_CHANGE_TEAM_DOWNLOAD_TIME",
  [SSERV_CMD_GLOB_DISABLE_TEAM_DOWNLOAD_TIME] = "GLOB_DISABLE_TEAM_DOWNLOAD_TIME",
  [SSERV_CMD_GLOB_CHANGE_CPU_BOGOMIPS] = "GLOB_CHANGE_CPU_BOGOMIPS",
  [SSERV_CMD_GLOB_DETECT_CPU_BOGOMIPS] = "GLOB_DETECT_CPU_BOGOMIPS",
  [SSERV_CMD_GLOB_CHANGE_SECURE_RUN] = "GLOB_CHANGE_SECURE_RUN",
  [SSERV_CMD_GLOB_CHANGE_DETECT_VIOLATIONS] = "GLOB_CHANGE_DETECT_VIOLATIONS",
  [SSERV_CMD_GLOB_CHANGE_ENABLE_MEMORY_LIMIT_ERROR] = "GLOB_CHANGE_ENABLE_MEMORY_LIMIT_ERROR",
  [SSERV_CMD_GLOB_CHANGE_SEPARATE_USER_SCORE] = "GLOB_CHANGE_SEPARATE_USER_SCORE",
  [SSERV_CMD_GLOB_CHANGE_STAND_ROW_ATTR] = "GLOB_CHANGE_STAND_ROW_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_ROW_ATTR] = "GLOB_CLEAR_STAND_ROW_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_PAGE_TABLE_ATTR] = "GLOB_CHANGE_STAND_PAGE_TABLE_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_PAGE_TABLE_ATTR] = "GLOB_CLEAR_STAND_PAGE_TABLE_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_PAGE_CUR_ATTR] = "GLOB_CHANGE_STAND_PAGE_CUR_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_PAGE_CUR_ATTR] = "GLOB_CLEAR_STAND_PAGE_CUR_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_PAGE_ROW_ATTR] = "GLOB_CHANGE_STAND_PAGE_ROW_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_PAGE_ROW_ATTR] = "GLOB_CLEAR_STAND_PAGE_ROW_ATTR",
  [SSERV_CMD_GLOB_CHANGE_STAND_PAGE_COL_ATTR] = "GLOB_CHANGE_STAND_PAGE_COL_ATTR",
  [SSERV_CMD_GLOB_CLEAR_STAND_PAGE_COL_ATTR] = "GLOB_CLEAR_STAND_PAGE_COL_ATTR",
  [SSERV_CMD_GLOB_CHANGE_LOAD_USER_GROUP] = "GLOB_CHANGE_LOAD_USER_GROUP",
  [SSERV_CMD_GLOB_CLEAR_LOAD_USER_GROUP] = "GLOB_CLEAR_LOAD_USER_GROUP",
  [SSERV_CMD_GLOB_CHANGE_CLARDB_PLUGIN] = "GLOB_CHANGE_CLARDB_PLUGIN",
  [SSERV_CMD_GLOB_CLEAR_CLARDB_PLUGIN] = "GLOB_CLEAR_CLARDB_PLUGIN",
  [SSERV_CMD_GLOB_CHANGE_RUNDB_PLUGIN] = "GLOB_CHANGE_RUNDB_PLUGIN",
  [SSERV_CMD_GLOB_CLEAR_RUNDB_PLUGIN] = "GLOB_CLEAR_RUNDB_PLUGIN",
  [SSERV_CMD_GLOB_CHANGE_XUSER_PLUGIN] = "GLOB_CHANGE_XUSER_PLUGIN",
  [SSERV_CMD_GLOB_CLEAR_XUSER_PLUGIN] = "GLOB_CLEAR_XUSER_PLUGIN",
  [SSERV_CMD_GLOB_CHANGE_COMPILE_MAX_VM_SIZE] = "GLOB_CHANGE_COMPILE_MAX_VM_SIZE",
  [SSERV_CMD_GLOB_CHANGE_COMPILE_MAX_STACK_SIZE] = "GLOB_CHANGE_COMPILE_MAX_STACK_SIZE",
  [SSERV_CMD_GLOB_CHANGE_COMPILE_MAX_FILE_SIZE] = "GLOB_CHANGE_COMPILE_MAX_FILE_SIZE",
  [SSERV_CMD_LANG_CHANGE_DISABLED] = "LANG_CHANGE_DISABLED",
  [SSERV_CMD_LANG_CHANGE_INSECURE] = "LANG_CHANGE_INSECURE",
  [SSERV_CMD_LANG_CHANGE_LONG_NAME] = "LANG_CHANGE_LONG_NAME",
  [SSERV_CMD_LANG_CLEAR_LONG_NAME] = "LANG_CLEAR_LONG_NAME",
  [SSERV_CMD_LANG_CHANGE_EXTID] = "LANG_CHANGE_EXTID",
  [SSERV_CMD_LANG_CLEAR_EXTID] = "LANG_CLEAR_EXTID",
  [SSERV_CMD_LANG_CHANGE_DISABLE_SECURITY] = "LANG_CHANGE_DISABLE_SECURITY",
  [SSERV_CMD_LANG_CHANGE_DISABLE_AUTO_TESTING] = "LANG_CHANGE_DISABLE_AUTO_TESTING",
  [SSERV_CMD_LANG_CHANGE_DISABLE_TESTING] = "LANG_CHANGE_DISABLE_TESTING",
  [SSERV_CMD_LANG_CHANGE_BINARY] = "LANG_CHANGE_BINARY",
  [SSERV_CMD_LANG_CHANGE_IS_DOS] = "LANG_CHANGE_IS_DOS",
  [SSERV_CMD_LANG_CHANGE_MAX_VM_SIZE] = "LANG_CHANGE_MAX_VM_SIZE",
  [SSERV_CMD_LANG_CHANGE_MAX_STACK_SIZE] = "LANG_CHANGE_MAX_STACK_SIZE",
  [SSERV_CMD_LANG_CHANGE_MAX_FILE_SIZE] = "LANG_CHANGE_MAX_FILE_SIZE",
  [SSERV_CMD_LANG_CHANGE_CONTENT_TYPE] = "LANG_CHANGE_CONTENT_TYPE",
  [SSERV_CMD_LANG_CLEAR_CONTENT_TYPE] = "LANG_CLEAR_CONTENT_TYPE",
  [SSERV_CMD_LANG_CHANGE_OPTS] = "LANG_CHANGE_OPTS",
  [SSERV_CMD_LANG_CLEAR_OPTS] = "LANG_CLEAR_OPTS",
  [SSERV_CMD_LANG_CHANGE_LIBS] = "LANG_CHANGE_LIBS",
  [SSERV_CMD_LANG_CLEAR_LIBS] = "LANG_CLEAR_LIBS",
  [SSERV_CMD_LANG_CHANGE_STYLE_CHECKER_CMD] = "LANG_CHANGE_STYLE_CHECKER_CMD",
  [SSERV_CMD_LANG_CLEAR_STYLE_CHECKER_CMD] = "LANG_CLEAR_STYLE_CHECKER_CMD",
  [SSERV_CMD_LANG_CHANGE_STYLE_CHECKER_ENV] = "LANG_CHANGE_STYLE_CHECKER_ENV",
  [SSERV_CMD_LANG_CLEAR_STYLE_CHECKER_ENV] = "LANG_CLEAR_STYLE_CHECKER_ENV",
  [SSERV_CMD_PROB_DELETE] = "PROB_DELETE",
  [SSERV_CMD_PROB_CHANGE_SHORT_NAME] = "PROB_CHANGE_SHORT_NAME",
  [SSERV_CMD_PROB_CLEAR_SHORT_NAME] = "PROB_CLEAR_SHORT_NAME",
  [SSERV_CMD_PROB_CHANGE_LONG_NAME] = "PROB_CHANGE_LONG_NAME",
  [SSERV_CMD_PROB_CLEAR_LONG_NAME] = "PROB_CLEAR_LONG_NAME",
  [SSERV_CMD_PROB_CHANGE_STAND_NAME] = "PROB_CHANGE_STAND_NAME",
  [SSERV_CMD_PROB_CLEAR_STAND_NAME] = "PROB_CLEAR_STAND_NAME",
  [SSERV_CMD_PROB_CHANGE_STAND_COLUMN] = "PROB_CHANGE_STAND_COLUMN",
  [SSERV_CMD_PROB_CLEAR_STAND_COLUMN] = "PROB_CLEAR_STAND_COLUMN",
  [SSERV_CMD_PROB_CHANGE_INTERNAL_NAME] = "PROB_CHANGE_INTERNAL_NAME",
  [SSERV_CMD_PROB_CLEAR_INTERNAL_NAME] = "PROB_CLEAR_INTERNAL_NAME",
  [SSERV_CMD_PROB_CHANGE_SUPER] = "PROB_CHANGE_SUPER",
  [SSERV_CMD_PROB_CHANGE_TYPE] = "PROB_CHANGE_TYPE",
  [SSERV_CMD_PROB_CHANGE_SCORING_CHECKER] = "PROB_CHANGE_SCORING_CHECKER",
  [SSERV_CMD_PROB_CHANGE_INTERACTIVE_VALUER] = "PROB_CHANGE_INTERACTIVE_VALUER",
  [SSERV_CMD_PROB_CHANGE_DISABLE_PE] = "PROB_CHANGE_DISABLE_PE",
  [SSERV_CMD_PROB_CHANGE_DISABLE_WTL] = "PROB_CHANGE_DISABLE_WTL",
  [SSERV_CMD_PROB_CHANGE_MANUAL_CHECKING] = "PROB_CHANGE_MANUAL_CHECKING",
  [SSERV_CMD_PROB_CHANGE_EXAMINATOR_NUM] = "PROB_CHANGE_EXAMINATOR_NUM",
  [SSERV_CMD_PROB_CHANGE_CHECK_PRESENTATION] = "PROB_CHANGE_CHECK_PRESENTATION",
  [SSERV_CMD_PROB_CHANGE_USE_STDIN] = "PROB_CHANGE_USE_STDIN",
  [SSERV_CMD_PROB_CHANGE_USE_STDOUT] = "PROB_CHANGE_USE_STDOUT",
  [SSERV_CMD_PROB_CHANGE_COMBINED_STDIN] = "PROB_CHANGE_COMBINED_STDIN",
  [SSERV_CMD_PROB_CHANGE_COMBINED_STDOUT] = "PROB_CHANGE_COMBINED_STDOUT",
  [SSERV_CMD_PROB_CHANGE_BINARY_INPUT] = "PROB_CHANGE_BINARY_INPUT",
  [SSERV_CMD_PROB_CHANGE_BINARY] = "PROB_CHANGE_BINARY",
  [SSERV_CMD_PROB_CHANGE_IGNORE_EXIT_CODE] = "PROB_CHANGE_IGNORE_EXIT_CODE",
  [SSERV_CMD_PROB_CHANGE_OLYMPIAD_MODE] = "PROB_CHANGE_OLYMPIAD_MODE",
  [SSERV_CMD_PROB_CHANGE_SCORE_LATEST] = "PROB_CHANGE_SCORE_LATEST",
  [SSERV_CMD_PROB_CHANGE_SCORE_LATEST_OR_UNMARKED] = "PROB_CHANGE_SCORE_LATEST_OR_UNMARKED",
  [SSERV_CMD_PROB_CHANGE_SCORE_LATEST_MARKED] = "PROB_CHANGE_SCORE_LATEST_MARKED",
  [SSERV_CMD_PROB_CHANGE_SCORE_TOKENIZED] = "PROB_CHANGE_SCORE_TOKENIZED",
  [SSERV_CMD_PROB_CHANGE_TIME_LIMIT] = "PROB_CHANGE_TIME_LIMIT",
  [SSERV_CMD_PROB_CHANGE_TIME_LIMIT_MILLIS] = "PROB_CHANGE_TIME_LIMIT_MILLIS",
  [SSERV_CMD_PROB_CHANGE_REAL_TIME_LIMIT] = "PROB_CHANGE_REAL_TIME_LIMIT",
  [SSERV_CMD_PROB_CHANGE_USE_AC_NOT_OK] = "PROB_CHANGE_USE_AC_NOT_OK",
  [SSERV_CMD_PROB_CHANGE_IGNORE_PREV_AC] = "PROB_CHANGE_IGNORE_PREV_AC",
  [SSERV_CMD_PROB_CHANGE_TEAM_ENABLE_REP_VIEW] = "PROB_CHANGE_TEAM_ENABLE_REP_VIEW",
  [SSERV_CMD_PROB_CHANGE_TEAM_ENABLE_CE_VIEW] = "PROB_CHANGE_TEAM_ENABLE_CE_VIEW",
  [SSERV_CMD_PROB_CHANGE_TEAM_SHOW_JUDGE_REPORT] = "PROB_CHANGE_TEAM_SHOW_JUDGE_REPORT",
  [SSERV_CMD_PROB_CHANGE_SHOW_CHECKER_COMMENT] = "PROB_CHANGE_SHOW_CHECKER_COMMENT",
  [SSERV_CMD_PROB_CHANGE_IGNORE_COMPILE_ERRORS] = "PROB_CHANGE_IGNORE_COMPILE_ERRORS",
  [SSERV_CMD_PROB_CHANGE_DISABLE_USER_SUBMIT] = "PROB_CHANGE_DISABLE_USER_SUBMIT",
  [SSERV_CMD_PROB_CHANGE_DISABLE_TAB] = "PROB_CHANGE_DISABLE_TAB",
  [SSERV_CMD_PROB_CHANGE_UNRESTRICTED_STATEMENT] = "PROB_CHANGE_UNRESTRICTED_STATEMENT",
  [SSERV_CMD_PROB_CHANGE_HIDE_FILE_NAMES] = "PROB_CHANGE_HIDE_FILE_NAMES",
  [SSERV_CMD_PROB_CHANGE_HIDE_REAL_TIME_LIMIT] = "PROB_CHANGE_HIDE_REAL_TIME_LIMIT",
  [SSERV_CMD_PROB_CHANGE_ENABLE_TOKENS] = "PROB_CHANGE_ENABLE_TOKENS",
  [SSERV_CMD_PROB_CHANGE_TOKENS_FOR_USER_AC] = "PROB_CHANGE_TOKENS_FOR_USER_AC",
  [SSERV_CMD_PROB_CHANGE_DISABLE_SUBMIT_AFTER_OK] = "PROB_CHANGE_DISABLE_SUBMIT_AFTER_OK",
  [SSERV_CMD_PROB_CHANGE_DISABLE_SECURITY] = "PROB_CHANGE_DISABLE_SECURITY",
  [SSERV_CMD_PROB_CHANGE_DISABLE_TESTING] = "PROB_CHANGE_DISABLE_TESTING",
  [SSERV_CMD_PROB_CHANGE_DISABLE_AUTO_TESTING] = "PROB_CHANGE_DISABLE_AUTO_TESTING",
  [SSERV_CMD_PROB_CHANGE_ENABLE_COMPILATION] = "PROB_CHANGE_ENABLE_COMPILATION",
  [SSERV_CMD_PROB_CHANGE_FULL_SCORE] = "PROB_CHANGE_FULL_SCORE",
  [SSERV_CMD_PROB_CHANGE_FULL_USER_SCORE] = "PROB_CHANGE_FULL_USER_SCORE",
  [SSERV_CMD_PROB_CHANGE_TEST_SCORE] = "PROB_CHANGE_TEST_SCORE",
  [SSERV_CMD_PROB_CHANGE_RUN_PENALTY] = "PROB_CHANGE_RUN_PENALTY",
  [SSERV_CMD_PROB_CHANGE_ACM_RUN_PENALTY] = "PROB_CHANGE_ACM_RUN_PENALTY",
  [SSERV_CMD_PROB_CHANGE_DISQUALIFIED_PENALTY] = "PROB_CHANGE_DISQUALIFIED_PENALTY",
  [SSERV_CMD_PROB_CHANGE_VARIABLE_FULL_SCORE] = "PROB_CHANGE_VARIABLE_FULL_SCORE",
  [SSERV_CMD_PROB_CHANGE_TEST_SCORE_LIST] = "PROB_CHANGE_TEST_SCORE_LIST",
  [SSERV_CMD_PROB_CLEAR_TEST_SCORE_LIST] = "PROB_CLEAR_TEST_SCORE_LIST",
  [SSERV_CMD_PROB_CHANGE_TOKENS] = "PROB_CHANGE_TOKENS",
  [SSERV_CMD_PROB_CLEAR_TOKENS] = "PROB_CLEAR_TOKENS",
  [SSERV_CMD_PROB_CHANGE_UMASK] = "PROB_CHANGE_UMASK",
  [SSERV_CMD_PROB_CLEAR_UMASK] = "PROB_CLEAR_UMASK",
  [SSERV_CMD_PROB_CHANGE_OK_STATUS] = "PROB_CHANGE_OK_STATUS",
  [SSERV_CMD_PROB_CLEAR_OK_STATUS] = "PROB_CLEAR_OK_STATUS",
  [SSERV_CMD_PROB_CHANGE_SCORE_TESTS] = "PROB_CHANGE_SCORE_TESTS",
  [SSERV_CMD_PROB_CLEAR_SCORE_TESTS] = "PROB_CLEAR_SCORE_TESTS",
  [SSERV_CMD_PROB_CHANGE_TESTS_TO_ACCEPT] = "PROB_CHANGE_TESTS_TO_ACCEPT",
  [SSERV_CMD_PROB_CHANGE_ACCEPT_PARTIAL] = "PROB_CHANGE_ACCEPT_PARTIAL",
  [SSERV_CMD_PROB_CHANGE_MIN_TESTS_TO_ACCEPT] = "PROB_CHANGE_MIN_TESTS_TO_ACCEPT",
  [SSERV_CMD_PROB_CHANGE_HIDDEN] = "PROB_CHANGE_HIDDEN",
  [SSERV_CMD_PROB_CHANGE_STAND_HIDE_TIME] = "PROB_CHANGE_STAND_HIDE_TIME",
  [SSERV_CMD_PROB_CHANGE_ADVANCE_TO_NEXT] = "PROB_CHANGE_ADVANCE_TO_NEXT",
  [SSERV_CMD_PROB_CHANGE_DISABLE_CTRL_CHARS] = "PROB_CHANGE_DISABLE_CTRL_CHARS",
  [SSERV_CMD_PROB_CHANGE_VALUER_SETS_MARKED] = "PROB_CHANGE_VALUER_SETS_MARKED",
  [SSERV_CMD_PROB_CHANGE_IGNORE_UNMARKED] = "PROB_CHANGE_IGNORE_UNMARKED",  
  [SSERV_CMD_PROB_CHANGE_DISABLE_STDERR] = "PROB_CHANGE_DISABLE_STDERR",
  [SSERV_CMD_PROB_CHANGE_ENABLE_PROCESS_GROUP] = "PROB_CHANGE_ENABLE_PROCESS_GROUP",
  [SSERV_CMD_PROB_CHANGE_HIDE_VARIANT] = "PROB_CHANGE_HIDE_VARIANT",
  [SSERV_CMD_PROB_CHANGE_AUTOASSIGN_VARIANTS] = "PROB_CHANGE_AUTOASSIGN_VARIANTS",
  [SSERV_CMD_PROB_CHANGE_ENABLE_TEXT_FORM] = "PROB_CHANGE_ENABLE_TEXT_FORM",
  [SSERV_CMD_PROB_CHANGE_STAND_IGNORE_SCORE] = "PROB_CHANGE_STAND_IGNORE_SCORE",
  [SSERV_CMD_PROB_CHANGE_STAND_LAST_COLUMN] = "PROB_CHANGE_STAND_LAST_COLUMN",
  [SSERV_CMD_PROB_CHANGE_CHECKER_REAL_TIME_LIMIT] = "PROB_CHANGE_CHECKER_REAL_TIME_LIMIT",
  [SSERV_CMD_PROB_CHANGE_INTERACTOR_TIME_LIMIT] = "PROB_CHANGE_INTERACTOR_TIME_LIMIT",
  [SSERV_CMD_PROB_CHANGE_MAX_VM_SIZE] = "PROB_CHANGE_MAX_VM_SIZE",
  [SSERV_CMD_PROB_CHANGE_MAX_STACK_SIZE] = "PROB_CHANGE_MAX_STACK_SIZE",
  [SSERV_CMD_PROB_CHANGE_MAX_CORE_SIZE] = "PROB_CHANGE_MAX_CORE_SIZE",
  [SSERV_CMD_PROB_CHANGE_MAX_FILE_SIZE] = "PROB_CHANGE_MAX_FILE_SIZE",
  [SSERV_CMD_PROB_CHANGE_MAX_OPEN_FILE_COUNT] = "PROB_CHANGE_MAX_OPEN_FILE_COUNT",
  [SSERV_CMD_PROB_CHANGE_MAX_PROCESS_COUNT] = "PROB_CHANGE_MAX_PROCESS_COUNT",
  [SSERV_CMD_PROB_CHANGE_MAX_USER_RUN_COUNT] = "PROB_CHANGE_MAX_USER_RUN_COUNT",
  [SSERV_CMD_PROB_CHANGE_INPUT_FILE] = "PROB_CHANGE_INPUT_FILE",
  [SSERV_CMD_PROB_CLEAR_INPUT_FILE] = "PROB_CLEAR_INPUT_FILE",
  [SSERV_CMD_PROB_CHANGE_OUTPUT_FILE] = "PROB_CHANGE_OUTPUT_FILE",
  [SSERV_CMD_PROB_CLEAR_OUTPUT_FILE] = "PROB_CLEAR_OUTPUT_FILE",
  [SSERV_CMD_PROB_CHANGE_USE_CORR] = "PROB_CHANGE_USE_CORR",
  [SSERV_CMD_PROB_CHANGE_USE_INFO] = "PROB_CHANGE_USE_INFO",
  [SSERV_CMD_PROB_CHANGE_USE_TGZ] = "PROB_CHANGE_USE_TGZ",
  [SSERV_CMD_PROB_CHANGE_TEST_DIR] = "PROB_CHANGE_TEST_DIR",
  [SSERV_CMD_PROB_CLEAR_TEST_DIR] = "PROB_CLEAR_TEST_DIR",
  [SSERV_CMD_PROB_CHANGE_CORR_DIR] = "PROB_CHANGE_CORR_DIR",
  [SSERV_CMD_PROB_CLEAR_CORR_DIR] = "PROB_CLEAR_CORR_DIR",
  [SSERV_CMD_PROB_CHANGE_INFO_DIR] = "PROB_CHANGE_INFO_DIR",
  [SSERV_CMD_PROB_CLEAR_INFO_DIR] = "PROB_CLEAR_INFO_DIR",
  [SSERV_CMD_PROB_CHANGE_TEST_SFX] = "PROB_CHANGE_TEST_SFX",
  [SSERV_CMD_PROB_CLEAR_TEST_SFX] = "PROB_CLEAR_TEST_SFX",
  [SSERV_CMD_PROB_CHANGE_TEST_PAT] = "PROB_CHANGE_TEST_PAT",
  [SSERV_CMD_PROB_CLEAR_TEST_PAT] = "PROB_CLEAR_TEST_PAT",
  [SSERV_CMD_PROB_CHANGE_CORR_SFX] = "PROB_CHANGE_CORR_SFX",
  [SSERV_CMD_PROB_CLEAR_CORR_SFX] = "PROB_CLEAR_CORR_SFX",
  [SSERV_CMD_PROB_CHANGE_CORR_PAT] = "PROB_CHANGE_CORR_PAT",
  [SSERV_CMD_PROB_CLEAR_CORR_PAT] = "PROB_CLEAR_CORR_PAT",
  [SSERV_CMD_PROB_CHANGE_INFO_SFX] = "PROB_CHANGE_INFO_SFX",
  [SSERV_CMD_PROB_CLEAR_INFO_SFX] = "PROB_CLEAR_INFO_SFX",
  [SSERV_CMD_PROB_CHANGE_INFO_PAT] = "PROB_CHANGE_INFO_PAT",
  [SSERV_CMD_PROB_CLEAR_INFO_PAT] = "PROB_CLEAR_INFO_PAT",
  [SSERV_CMD_PROB_CHANGE_TGZ_SFX] = "PROB_CHANGE_TGZ_SFX",
  [SSERV_CMD_PROB_CLEAR_TGZ_SFX] = "PROB_CLEAR_TGZ_SFX",
  [SSERV_CMD_PROB_CHANGE_TGZ_PAT] = "PROB_CHANGE_TGZ_PAT",
  [SSERV_CMD_PROB_CLEAR_TGZ_PAT] = "PROB_CLEAR_TGZ_PAT",
  [SSERV_CMD_PROB_CHANGE_TGZDIR_SFX] = "PROB_CHANGE_TGZDIR_SFX",
  [SSERV_CMD_PROB_CLEAR_TGZDIR_SFX] = "PROB_CLEAR_TGZDIR_SFX",
  [SSERV_CMD_PROB_CHANGE_TGZDIR_PAT] = "PROB_CHANGE_TGZDIR_PAT",
  [SSERV_CMD_PROB_CLEAR_TGZDIR_PAT] = "PROB_CLEAR_TGZDIR_PAT",
  [SSERV_CMD_PROB_CHANGE_STANDARD_CHECKER] = "PROB_CHANGE_STANDARD_CHECKER",
  [SSERV_CMD_PROB_CHANGE_SCORE_BONUS] = "PROB_CHANGE_SCORE_BONUS",
  [SSERV_CMD_PROB_CLEAR_SCORE_BONUS] = "PROB_CLEAR_SCORE_BONUS",
  [SSERV_CMD_PROB_CHANGE_OPEN_TESTS] = "PROB_CHANGE_OPEN_TESTS",
  [SSERV_CMD_PROB_CLEAR_OPEN_TESTS] = "PROB_CLEAR_OPEN_TESTS",
  [SSERV_CMD_PROB_CHANGE_FINAL_OPEN_TESTS] = "PROB_CHANGE_FINAL_OPEN_TESTS",
  [SSERV_CMD_PROB_CLEAR_FINAL_OPEN_TESTS] = "PROB_CLEAR_FINAL_OPEN_TESTS",
  [SSERV_CMD_PROB_CHANGE_TOKEN_OPEN_TESTS] = "PROB_CHANGE_TOKEN_OPEN_TESTS",
  [SSERV_CMD_PROB_CLEAR_TOKEN_OPEN_TESTS] = "PROB_CLEAR_TOKEN_OPEN_TESTS",
  [SSERV_CMD_PROB_CHANGE_LANG_COMPILER_ENV] = "PROB_CHANGE_LANG_COMPILER_ENV",
  [SSERV_CMD_PROB_CLEAR_LANG_COMPILER_ENV] = "PROB_CLEAR_LANG_COMPILER_ENV",
  [SSERV_CMD_PROB_CHANGE_CHECK_CMD] = "PROB_CHANGE_CHECK_CMD",
  [SSERV_CMD_PROB_CLEAR_CHECK_CMD] = "PROB_CLEAR_CHECK_CMD",
  [SSERV_CMD_PROB_CHANGE_CHECKER_ENV] = "PROB_CHANGE_CHECKER_ENV",
  [SSERV_CMD_PROB_CLEAR_CHECKER_ENV] = "PROB_CLEAR_CHECKER_ENV",
  [SSERV_CMD_PROB_CHANGE_VALUER_CMD] = "PROB_CHANGE_VALUER_CMD",
  [SSERV_CMD_PROB_CLEAR_VALUER_CMD] = "PROB_CLEAR_VALUER_CMD",
  [SSERV_CMD_PROB_CHANGE_VALUER_ENV] = "PROB_CHANGE_VALUER_ENV",
  [SSERV_CMD_PROB_CLEAR_VALUER_ENV] = "PROB_CLEAR_VALUER_ENV",
  [SSERV_CMD_PROB_CHANGE_INTERACTOR_CMD] = "PROB_CHANGE_INTERACTOR_CMD",
  [SSERV_CMD_PROB_CLEAR_INTERACTOR_CMD] = "PROB_CLEAR_INTERACTOR_CMD",
  [SSERV_CMD_PROB_CHANGE_INTERACTOR_ENV] = "PROB_CHANGE_INTERACTOR_ENV",
  [SSERV_CMD_PROB_CLEAR_INTERACTOR_ENV] = "PROB_CLEAR_INTERACTOR_ENV",
  [SSERV_CMD_PROB_CHANGE_STYLE_CHECKER_CMD] = "PROB_CHANGE_STYLE_CHECKER_CMD",
  [SSERV_CMD_PROB_CLEAR_STYLE_CHECKER_CMD] = "PROB_CLEAR_STYLE_CHECKER_CMD",
  [SSERV_CMD_PROB_CHANGE_STYLE_CHECKER_ENV] = "PROB_CHANGE_STYLE_CHECKER_ENV",
  [SSERV_CMD_PROB_CLEAR_STYLE_CHECKER_ENV] = "PROB_CLEAR_STYLE_CHECKER_ENV",
  [SSERV_CMD_PROB_CHANGE_TEST_CHECKER_CMD] = "PROB_CHANGE_TEST_CHECKER_CMD",
  [SSERV_CMD_PROB_CLEAR_TEST_CHECKER_CMD] = "PROB_CLEAR_TEST_CHECKER_CMD",
  [SSERV_CMD_PROB_CHANGE_TEST_CHECKER_ENV] = "PROB_CHANGE_TEST_CHECKER_ENV",
  [SSERV_CMD_PROB_CLEAR_TEST_CHECKER_ENV] = "PROB_CLEAR_TEST_CHECKER_ENV",
  [SSERV_CMD_PROB_CHANGE_INIT_CMD] = "PROB_CHANGE_INIT_CMD",
  [SSERV_CMD_PROB_CLEAR_INIT_CMD] = "PROB_CLEAR_INIT_CMD",
  [SSERV_CMD_PROB_CHANGE_START_CMD] = "PROB_CHANGE_START_CMD",
  [SSERV_CMD_PROB_CLEAR_START_CMD] = "PROB_CLEAR_START_CMD",
  [SSERV_CMD_PROB_CHANGE_INIT_ENV] = "PROB_CHANGE_INIT_ENV",
  [SSERV_CMD_PROB_CLEAR_INIT_ENV] = "PROB_CLEAR_INIT_ENV",
  [SSERV_CMD_PROB_CHANGE_START_ENV] = "PROB_CHANGE_START_ENV",
  [SSERV_CMD_PROB_CLEAR_START_ENV] = "PROB_CLEAR_START_ENV",
  [SSERV_CMD_PROB_CHANGE_SOLUTION_SRC] = "PROB_CHANGE_SOLUTION_SRC",
  [SSERV_CMD_PROB_CLEAR_SOLUTION_SRC] = "PROB_CLEAR_SOLUTION_SRC",
  [SSERV_CMD_PROB_CHANGE_SOLUTION_CMD] = "PROB_CHANGE_SOLUTION_CMD",
  [SSERV_CMD_PROB_CLEAR_SOLUTION_CMD] = "PROB_CLEAR_SOLUTION_CMD",
  [SSERV_CMD_PROB_CHANGE_LANG_TIME_ADJ] = "PROB_CHANGE_LANG_TIME_ADJ",
  [SSERV_CMD_PROB_CLEAR_LANG_TIME_ADJ] = "PROB_CLEAR_LANG_TIME_ADJ",
  [SSERV_CMD_PROB_CHANGE_LANG_TIME_ADJ_MILLIS] = "PROB_CHANGE_LANG_TIME_ADJ_MILLIS",
  [SSERV_CMD_PROB_CLEAR_LANG_TIME_ADJ_MILLIS] = "PROB_CLEAR_LANG_TIME_ADJ_MILLIS",
  [SSERV_CMD_PROB_CHANGE_LANG_MAX_VM_SIZE] = "PROB_CHANGE_LANG_MAX_VM_SIZE",
  [SSERV_CMD_PROB_CLEAR_LANG_MAX_VM_SIZE] = "PROB_CLEAR_LANG_MAX_VM_SIZE",
  [SSERV_CMD_PROB_CHANGE_LANG_MAX_STACK_SIZE] = "PROB_CHANGE_LANG_MAX_STACK_SIZE",
  [SSERV_CMD_PROB_CLEAR_LANG_MAX_STACK_SIZE] = "PROB_CLEAR_LANG_MAX_STACK_SIZE",
  [SSERV_CMD_PROB_CHANGE_DISABLE_LANGUAGE] = "PROB_CHANGE_DISABLE_LANGUAGE",
  [SSERV_CMD_PROB_CLEAR_DISABLE_LANGUAGE] = "PROB_CLEAR_DISABLE_LANGUAGE",
  [SSERV_CMD_PROB_CHANGE_ENABLE_LANGUAGE] = "PROB_CHANGE_ENABLE_LANGUAGE",
  [SSERV_CMD_PROB_CLEAR_ENABLE_LANGUAGE] = "PROB_CLEAR_ENABLE_LANGUAGE",
  [SSERV_CMD_PROB_CHANGE_REQUIRE] = "PROB_CHANGE_REQUIRE",
  [SSERV_CMD_PROB_CLEAR_REQUIRE] = "PROB_CLEAR_REQUIRE",
  [SSERV_CMD_PROB_CHANGE_PROVIDE_OK] = "PROB_CHANGE_PROVIDE_OK",
  [SSERV_CMD_PROB_CLEAR_PROVIDE_OK] = "PROB_CLEAR_PROVIDE_OK",
  [SSERV_CMD_PROB_CHANGE_TEST_SETS] = "PROB_CHANGE_TEST_SETS",
  [SSERV_CMD_PROB_CLEAR_TEST_SETS] = "PROB_CLEAR_TEST_SETS",
  [SSERV_CMD_PROB_CHANGE_SCORE_VIEW] = "PROB_CHANGE_SCORE_VIEW",
  [SSERV_CMD_PROB_CLEAR_SCORE_VIEW] = "PROB_CLEAR_SCORE_VIEW",
  [SSERV_CMD_PROB_CHANGE_START_DATE] = "PROB_CHANGE_START_DATE",
  [SSERV_CMD_PROB_CLEAR_START_DATE] = "PROB_CLEAR_START_DATE",
  [SSERV_CMD_PROB_CHANGE_DEADLINE] = "PROB_CHANGE_DEADLINE",
  [SSERV_CMD_PROB_CLEAR_DEADLINE] = "PROB_CLEAR_DEADLINE",
  [SSERV_CMD_PROB_CHANGE_VARIANT_NUM] = "PROB_CHANGE_VARIANT_NUM",
  [SSERV_CMD_PROB_CHANGE_VARIANTS] = "PROB_CHANGE_VARIANTS",
  [SSERV_CMD_PROB_DELETE_VARIANTS] = "PROB_DELETE_VARIANTS",
  [SSERV_CMD_PROB_CHANGE_XML_FILE] = "PROB_CHANGE_XML_FILE",
  [SSERV_CMD_PROB_CLEAR_XML_FILE] = "PROB_CLEAR_XML_FILE",
  [SSERV_CMD_PROB_CHANGE_ALTERNATIVES_FILE] = "PROB_CHANGE_ALTERNATIVES_FILE",
  [SSERV_CMD_PROB_CLEAR_ALTERNATIVES_FILE] = "PROB_CLEAR_ALTERNATIVES_FILE",
  [SSERV_CMD_PROB_CHANGE_PLUGIN_FILE] = "PROB_CHANGE_PLUGIN_FILE",
  [SSERV_CMD_PROB_CLEAR_PLUGIN_FILE] = "PROB_CLEAR_PLUGIN_FILE",
  [SSERV_CMD_PROB_CHANGE_STAND_ATTR] = "PROB_CHANGE_STAND_ATTR",
  [SSERV_CMD_PROB_CLEAR_STAND_ATTR] = "PROB_CLEAR_STAND_ATTR",
  [SSERV_CMD_PROB_CHANGE_SOURCE_HEADER] = "PROB_CHANGE_SOURCE_HEADER",
  [SSERV_CMD_PROB_CLEAR_SOURCE_HEADER] = "PROB_CLEAR_SOURCE_HEADER",
  [SSERV_CMD_PROB_CHANGE_SOURCE_FOOTER] = "PROB_CHANGE_SOURCE_FOOTER",
  [SSERV_CMD_PROB_CLEAR_SOURCE_FOOTER] = "PROB_CLEAR_SOURCE_FOOTER",
  [SSERV_CMD_PROB_CHANGE_NORMALIZATION] = "PROB_CHANGE_NORMALIZATION",
  [SSERV_CMD_PROB_CLEAR_NORMALIZATION] = "PROB_CLEAR_NORMALIZATION",
  [SSERV_CMD_LANG_UPDATE_VERSIONS] = "LANG_UPDATE_VERSIONS",
  [SSERV_CMD_PROB_CLEAR_VARIANTS] = "PROB_CLEAR_VARIANTS",
  [SSERV_CMD_PROB_RANDOM_VARIANTS] = "PROB_RANDOM_VARIANTS",
  [SSERV_CMD_LOGOUT] = "LOGOUT",
  [SSERV_CMD_HTTP_REQUEST] = "HTTP_REQUEST",
  [SSERV_CMD_VIEW_CNTS_DETAILS] = "VIEW_CNTS_DETAILS",
  [SSERV_CMD_EDITED_CNTS_BACK] = "EDITED_CNTS_BACK",
  [SSERV_CMD_EDITED_CNTS_CONTINUE] = "EDITED_CNTS_CONTINUE",
  [SSERV_CMD_EDITED_CNTS_START_NEW] = "EDITED_CNTS_START_NEW",
  [SSERV_CMD_LOCKED_CNTS_FORGET] = "LOCKED_CNTS_FORGET",
  [SSERV_CMD_LOCKED_CNTS_CONTINUE] = "LOCKED_CNTS_CONTINUE",
  [SSERV_CMD_EDIT_CONTEST_PAGE] = "EDIT_CONTEST_PAGE",
  [SSERV_CMD_EDIT_CONTEST_PAGE_2] = "EDIT_CONTEST_PAGE_2",
  [SSERV_CMD_CLEAR_CONTEST_XML_FIELD] = "CLEAR_CONTEST_XML_FIELD",
  [SSERV_CMD_EDIT_CONTEST_XML_FIELD] = "EDIT_CONTEST_XML_FIELD",
  [SSERV_CMD_TOGGLE_CONTEST_XML_VISIBILITY] = "TOGGLE_CONTEST_XML_VISIBILITY",
  [SSERV_CMD_CONTEST_XML_FIELD_EDIT_PAGE] = "CONTEST_XML_FIELD_EDIT_PAGE",
  [SSERV_CMD_SAVE_FILE_CONTEST_XML] = "SAVE_FILE_CONTEST_XML",
  [SSERV_CMD_CLEAR_FILE_CONTEST_XML] = "CLEAR_FILE_CONTEST_XML",
  [SSERV_CMD_RELOAD_FILE_CONTEST_XML] = "RELOAD_FILE_CONTEST_XML",
  [SSERV_CMD_COPY_ACCESS_RULES_PAGE] = "COPY_ACCESS_RULES_PAGE",
  [SSERV_CMD_COPY_ALL_ACCESS_RULES_PAGE] = "COPY_ALL_ACCESS_RULES_PAGE",
  [SSERV_CMD_COPY_ALL_ACCESS_RULES] = "COPY_ALL_ACCESS_RULES",
  [SSERV_CMD_COPY_ALL_PRIV_USERS_PAGE] = "COPY_ALL_PRIV_USERS_PAGE",
  [SSERV_CMD_COPY_ALL_PRIV_USERS] = "COPY_ALL_PRIV_USERS",
  [SSERV_CMD_ADD_PRIV_USER] = "ADD_PRIV_USER",
  [SSERV_CMD_EDIT_PERMISSIONS_PAGE] = "EDIT_PERMISSIONS_PAGE",
  [SSERV_CMD_EDIT_GENERAL_FIELDS_PAGE] = "EDIT_GENERAL_FIELDS_PAGE",
  [SSERV_CMD_EDIT_MEMBER_FIELDS_PAGE] = "EDIT_MEMBER_FIELDS_PAGE",
  [SSERV_CMD_DELETE_PRIV_USER] = "DELETE_PRIV_USER",
  [SSERV_CMD_SET_PREDEF_PRIV] = "SET_PREDEF_PRIV",
  [SSERV_CMD_SET_PRIV] = "SET_PRIV",
  [SSERV_CMD_SET_DEFAULT_ACCESS] = "SET_DEFAULT_ACCESS",
  [SSERV_CMD_CHECK_IP_MASK] = "CHECK_IP_MASK",
  [SSERV_CMD_ADD_IP] = "ADD_IP",
  [SSERV_CMD_SET_RULE_ACCESS] = "SET_RULE_ACCESS",
  [SSERV_CMD_SET_RULE_SSL] = "SET_RULE_SSL",
  [SSERV_CMD_SET_RULE_IP] = "SET_RULE_IP",
  [SSERV_CMD_DELETE_RULE] = "DELETE_RULE",
  [SSERV_CMD_FORWARD_RULE] = "FORWARD_RULE",
  [SSERV_CMD_BACKWARD_RULE] = "BACKWARD_RULE",
  [SSERV_CMD_COPY_ACCESS_RULES] = "COPY_ACCESS_RULES",
  [SSERV_CMD_EDIT_GENERAL_FIELDS] = "EDIT_GENERAL_FIELDS",
  [SSERV_CMD_EDIT_MEMBER_FIELDS] = "EDIT_MEMBER_FIELDS",
  [SSERV_CMD_CREATE_NEW_CONTEST_PAGE] = "CREATE_NEW_CONTEST_PAGE",
  [SSERV_CMD_CREATE_NEW_CONTEST] = "CREATE_NEW_CONTEST",
  [SSERV_CMD_FORGET_CONTEST] = "FORGET_CONTEST",
  [SSERV_CMD_EDIT_SERVE_GLOBAL_FIELD] = "EDIT_SERVE_GLOBAL_FIELD",
  [SSERV_CMD_CLEAR_SERVE_GLOBAL_FIELD] = "CLEAR_SERVE_GLOBAL_FIELD",
  [SSERV_CMD_EDIT_SID_STATE_FIELD] = "EDIT_SID_STATE_FIELD",
  [SSERV_CMD_EDIT_SID_STATE_FIELD_NEGATED] = "EDIT_SID_STATE_FIELD_NEGATED",
  [SSERV_CMD_EDIT_SERVE_GLOBAL_FIELD_DETAIL_PAGE] = "EDIT_SERVE_GLOBAL_FIELD_DETAIL_PAGE",
  [SSERV_CMD_EDIT_SERVE_GLOBAL_FIELD_DETAIL] = "EDIT_SERVE_GLOBAL_FIELD_DETAIL",
  [SSERV_CMD_SET_SID_STATE_LANG_FIELD] = "SET_SID_STATE_LANG_FIELD",
  [SSERV_CMD_CLEAR_SID_STATE_LANG_FIELD] = "CLEAR_SID_STATE_LANG_FIELD",
  [SSERV_CMD_SET_SERVE_LANG_FIELD] = "SET_SERVE_LANG_FIELD",
  [SSERV_CMD_CLEAR_SERVE_LANG_FIELD] = "CLEAR_SERVE_LANG_FIELD",
  [SSERV_CMD_EDIT_SERVE_LANG_FIELD_DETAIL_PAGE] = "EDIT_SERVE_LANG_FIELD_DETAIL_PAGE",
  [SSERV_CMD_EDIT_SERVE_LANG_FIELD_DETAIL] = "EDIT_SERVE_LANG_FIELD_DETAIL",
  [SSERV_CMD_SERVE_LANG_UPDATE_VERSIONS] = "SERVE_LANG_UPDATE_VERSIONS",
  [SSERV_CMD_CREATE_ABSTR_PROB] = "CREATE_ABSTR_PROB",
  [SSERV_CMD_CREATE_CONCRETE_PROB] = "CREATE_CONCRETE_PROB",
  [SSERV_CMD_DELETE_PROB] = "DELETE_PROB",
  [SSERV_CMD_SET_SID_STATE_PROB_FIELD] = "SET_SID_STATE_PROB_FIELD",
  [SSERV_CMD_SET_SERVE_PROB_FIELD] = "SET_SERVE_PROB_FIELD",
  [SSERV_CMD_CLEAR_SERVE_PROB_FIELD] = "CLEAR_SERVE_PROB_FIELD",
  [SSERV_CMD_EDIT_SERVE_PROB_FIELD_DETAIL_PAGE] = "EDIT_SERVE_PROB_FIELD_DETAIL_PAGE",
  [SSERV_CMD_EDIT_SERVE_PROB_FIELD_DETAIL] = "EDIT_SERVE_PROB_FIELD_DETAIL",
  [SSERV_CMD_BROWSE_PROBLEM_PACKAGES] = "BROWSE_PROBLEM_PACKAGES",
  [SSERV_CMD_CREATE_PACKAGE] = "CREATE_PACKAGE",
  [SSERV_CMD_CREATE_PROBLEM] = "CREATE_PROBLEM",
  [SSERV_CMD_DELETE_ITEM] = "DELETE_ITEM",
  [SSERV_CMD_EDIT_PROBLEM] = "EDIT_PROBLEM",
  [SSERV_CMD_USER_BROWSE_PAGE] = "USER_BROWSE_PAGE",
  [SSERV_CMD_USER_FILTER_CHANGE_ACTION] = "USER_FILTER_CHANGE_ACTION",
  [SSERV_CMD_USER_FILTER_FIRST_PAGE_ACTION] = "USER_FILTER_FIRST_PAGE_ACTION",
  [SSERV_CMD_USER_FILTER_PREV_PAGE_ACTION] = "USER_FILTER_PREV_PAGE_ACTION",
  [SSERV_CMD_USER_FILTER_NEXT_PAGE_ACTION] = "USER_FILTER_NEXT_PAGE_ACTION",
  [SSERV_CMD_USER_FILTER_LAST_PAGE_ACTION] = "USER_FILTER_LAST_PAGE_ACTION",
  [SSERV_CMD_USER_JUMP_CONTEST_ACTION] = "USER_JUMP_CONTEST_ACTION",
  [SSERV_CMD_USER_JUMP_GROUP_ACTION] = "USER_JUMP_GROUP_ACTION",
  [SSERV_CMD_USER_BROWSE_MARK_ALL_ACTION] = "USER_BROWSE_MARK_ALL_ACTION",
  [SSERV_CMD_USER_BROWSE_UNMARK_ALL_ACTION] = "USER_BROWSE_UNMARK_ALL_ACTION",
  [SSERV_CMD_USER_BROWSE_TOGGLE_ALL_ACTION] = "USER_BROWSE_TOGGLE_ALL_ACTION",
  [SSERV_CMD_USER_CREATE_ONE_PAGE] = "USER_CREATE_ONE_PAGE",
  [SSERV_CMD_USER_CREATE_ONE_ACTION] = "USER_CREATE_ONE_ACTION",
  [SSERV_CMD_USER_CREATE_MANY_PAGE] = "USER_CREATE_MANY_PAGE",
  [SSERV_CMD_USER_CREATE_MANY_ACTION] = "USER_CREATE_MANY_ACTION",
  [SSERV_CMD_USER_CREATE_FROM_CSV_PAGE] = "USER_CREATE_FROM_CSV_PAGE",
  [SSERV_CMD_USER_CREATE_FROM_CSV_ACTION] = "USER_CREATE_FROM_CSV_ACTION",
  [SSERV_CMD_USER_DETAIL_PAGE] = "USER_DETAIL_PAGE",
  [SSERV_CMD_USER_PASSWORD_PAGE] = "USER_PASSWORD_PAGE",
  [SSERV_CMD_USER_CHANGE_PASSWORD_ACTION] = "USER_CHANGE_PASSWORD_ACTION",
  [SSERV_CMD_USER_CNTS_PASSWORD_PAGE] = "USER_CNTS_PASSWORD_PAGE",
  [SSERV_CMD_USER_CHANGE_CNTS_PASSWORD_ACTION] = "USER_CHANGE_CNTS_PASSWORD_ACTION",
  [SSERV_CMD_USER_CLEAR_FIELD_ACTION] = "USER_CLEAR_FIELD_ACTION",
  [SSERV_CMD_USER_CREATE_MEMBER_ACTION] = "USER_CREATE_MEMBER_ACTION",
  [SSERV_CMD_USER_DELETE_MEMBER_PAGE] = "USER_DELETE_MEMBER_PAGE",
  [SSERV_CMD_USER_DELETE_MEMBER_ACTION] = "USER_DELETE_MEMBER_ACTION",
  [SSERV_CMD_USER_SAVE_AND_PREV_ACTION] = "USER_SAVE_AND_PREV_ACTION",
  [SSERV_CMD_USER_SAVE_ACTION] = "USER_SAVE_ACTION",
  [SSERV_CMD_USER_SAVE_AND_NEXT_ACTION] = "USER_SAVE_AND_NEXT_ACTION",
  [SSERV_CMD_USER_CANCEL_AND_PREV_ACTION] = "USER_CANCEL_AND_PREV_ACTION",
  [SSERV_CMD_USER_CANCEL_ACTION] = "USER_CANCEL_ACTION",
  [SSERV_CMD_USER_CANCEL_AND_NEXT_ACTION] = "USER_CANCEL_AND_NEXT_ACTION",
  [SSERV_CMD_USER_CREATE_REG_PAGE] = "USER_CREATE_REG_PAGE",
  [SSERV_CMD_USER_CREATE_REG_ACTION] = "USER_CREATE_REG_ACTION",
  [SSERV_CMD_USER_EDIT_REG_PAGE] = "USER_EDIT_REG_PAGE",
  [SSERV_CMD_USER_EDIT_REG_ACTION] = "USER_EDIT_REG_ACTION",
  [SSERV_CMD_USER_DELETE_REG_PAGE] = "USER_DELETE_REG_PAGE",
  [SSERV_CMD_USER_DELETE_REG_ACTION] = "USER_DELETE_REG_ACTION",
  [SSERV_CMD_USER_DELETE_SESSION_ACTION] = "USER_DELETE_SESSION_ACTION",
  [SSERV_CMD_USER_DELETE_ALL_SESSIONS_ACTION] = "USER_DELETE_ALL_SESSIONS_ACTION",
  [SSERV_CMD_USER_SEL_RANDOM_PASSWD_PAGE] = "USER_SEL_RANDOM_PASSWD_PAGE",
  [SSERV_CMD_USER_SEL_RANDOM_PASSWD_ACTION] = "USER_SEL_RANDOM_PASSWD_ACTION",
  [SSERV_CMD_USER_SEL_CLEAR_CNTS_PASSWD_PAGE] = "USER_SEL_CLEAR_CNTS_PASSWD_PAGE",
  [SSERV_CMD_USER_SEL_CLEAR_CNTS_PASSWD_ACTION] = "USER_SEL_CLEAR_CNTS_PASSWD_ACTION",
  [SSERV_CMD_USER_SEL_RANDOM_CNTS_PASSWD_PAGE] = "USER_SEL_RANDOM_CNTS_PASSWD_PAGE",
  [SSERV_CMD_USER_SEL_RANDOM_CNTS_PASSWD_ACTION] = "USER_SEL_RANDOM_CNTS_PASSWD_ACTION",
  [SSERV_CMD_USER_SEL_CREATE_REG_PAGE] = "USER_SEL_CREATE_REG_PAGE",
  [SSERV_CMD_USER_SEL_CREATE_REG_ACTION] = "USER_SEL_CREATE_REG_ACTION",
  [SSERV_CMD_USER_SEL_CREATE_REG_AND_COPY_PAGE] = "USER_SEL_CREATE_REG_AND_COPY_PAGE",
  [SSERV_CMD_USER_SEL_CREATE_REG_AND_COPY_ACTION] = "USER_SEL_CREATE_REG_AND_COPY_ACTION",
  [SSERV_CMD_USER_SEL_DELETE_REG_PAGE] = "USER_SEL_DELETE_REG_PAGE",
  [SSERV_CMD_USER_SEL_DELETE_REG_ACTION] = "USER_SEL_DELETE_REG_ACTION",
  [SSERV_CMD_USER_SEL_CHANGE_REG_STATUS_PAGE] = "USER_SEL_CHANGE_REG_STATUS_PAGE",
  [SSERV_CMD_USER_SEL_CHANGE_REG_STATUS_ACTION] = "USER_SEL_CHANGE_REG_STATUS_ACTION",
  [SSERV_CMD_USER_SEL_CHANGE_REG_FLAGS_PAGE] = "USER_SEL_CHANGE_REG_FLAGS_PAGE",
  [SSERV_CMD_USER_SEL_CHANGE_REG_FLAGS_ACTION] = "USER_SEL_CHANGE_REG_FLAGS_ACTION",
  [SSERV_CMD_USER_SEL_CANCEL_ACTION] = "USER_SEL_CANCEL_ACTION",
  [SSERV_CMD_USER_SEL_VIEW_PASSWD_PAGE] = "USER_SEL_VIEW_PASSWD_PAGE",
  [SSERV_CMD_USER_SEL_VIEW_CNTS_PASSWD_PAGE] = "USER_SEL_VIEW_CNTS_PASSWD_PAGE",
  [SSERV_CMD_USER_SEL_VIEW_PASSWD_REDIRECT] = "USER_SEL_VIEW_PASSWD_REDIRECT",
  [SSERV_CMD_USER_SEL_VIEW_CNTS_PASSWD_REDIRECT] = "USER_SEL_VIEW_CNTS_PASSWD_REDIRECT",
  [SSERV_CMD_USER_SEL_CREATE_GROUP_MEMBER_PAGE] = "USER_SEL_CREATE_GROUP_MEMBER_PAGE",
  [SSERV_CMD_USER_SEL_CREATE_GROUP_MEMBER_ACTION] = "USER_SEL_CREATE_GROUP_MEMBER_ACTION",
  [SSERV_CMD_USER_SEL_DELETE_GROUP_MEMBER_PAGE] = "USER_SEL_DELETE_GROUP_MEMBER_PAGE",
  [SSERV_CMD_USER_SEL_DELETE_GROUP_MEMBER_ACTION] = "USER_SEL_DELETE_GROUP_MEMBER_ACTION",
  [SSERV_CMD_USER_IMPORT_CSV_PAGE] = "USER_IMPORT_CSV_PAGE",
  [SSERV_CMD_USER_IMPORT_CSV_ACTION] = "USER_IMPORT_CSV_ACTION",
  [SSERV_CMD_GROUP_BROWSE_PAGE] = "GROUP_BROWSE_PAGE",
  [SSERV_CMD_GROUP_FILTER_CHANGE_ACTION] = "GROUP_FILTER_CHANGE_ACTION",
  [SSERV_CMD_GROUP_FILTER_FIRST_PAGE_ACTION] = "GROUP_FILTER_FIRST_PAGE_ACTION",
  [SSERV_CMD_GROUP_FILTER_PREV_PAGE_ACTION] = "GROUP_FILTER_PREV_PAGE_ACTION",
  [SSERV_CMD_GROUP_FILTER_NEXT_PAGE_ACTION] = "GROUP_FILTER_NEXT_PAGE_ACTION",
  [SSERV_CMD_GROUP_FILTER_LAST_PAGE_ACTION] = "GROUP_FILTER_LAST_PAGE_ACTION",
  [SSERV_CMD_GROUP_CREATE_PAGE] = "GROUP_CREATE_PAGE",
  [SSERV_CMD_GROUP_CREATE_ACTION] = "GROUP_CREATE_ACTION",
  [SSERV_CMD_GROUP_MODIFY_PAGE] = "GROUP_MODIFY_PAGE",
  [SSERV_CMD_GROUP_MODIFY_PAGE_ACTION] = "GROUP_MODIFY_PAGE_ACTION",
  [SSERV_CMD_GROUP_MODIFY_ACTION] = "GROUP_MODIFY_ACTION",
  [SSERV_CMD_GROUP_DELETE_PAGE] = "GROUP_DELETE_PAGE",
  [SSERV_CMD_GROUP_DELETE_PAGE_ACTION] = "GROUP_DELETE_PAGE_ACTION",
  [SSERV_CMD_GROUP_DELETE_ACTION] = "GROUP_DELETE_ACTION",
  [SSERV_CMD_GROUP_CANCEL_ACTION] = "GROUP_CANCEL_ACTION",
  [SSERV_CMD_TESTS_MAIN_PAGE] = "TESTS_MAIN_PAGE",
  [SSERV_CMD_TESTS_STATEMENT_EDIT_PAGE] = "TESTS_STATEMENT_EDIT_PAGE",
  [SSERV_CMD_TESTS_STATEMENT_EDIT_ACTION] = "TESTS_STATEMENT_EDIT_ACTION",
  [SSERV_CMD_TESTS_STATEMENT_EDIT_2_ACTION] = "TESTS_STATEMENT_EDIT_2_ACTION",
  [SSERV_CMD_TESTS_STATEMENT_EDIT_3_ACTION] = "TESTS_STATEMENT_EDIT_3_ACTION",
  [SSERV_CMD_TESTS_STATEMENT_EDIT_4_ACTION] = "TESTS_STATEMENT_EDIT_4_ACTION",
  [SSERV_CMD_TESTS_STATEMENT_EDIT_5_ACTION] = "TESTS_STATEMENT_EDIT_5_ACTION",
  [SSERV_CMD_TESTS_STATEMENT_DELETE_ACTION] = "TESTS_STATEMENT_DELETE_ACTION",
  [SSERV_CMD_TESTS_STATEMENT_DELETE_SAMPLE_ACTION] = "TESTS_STATEMENT_DELETE_SAMPLE_ACTION",
  [SSERV_CMD_TESTS_TESTS_VIEW_PAGE] = "TESTS_TESTS_VIEW_PAGE",
  [SSERV_CMD_TESTS_CHECK_TESTS_PAGE] = "TESTS_CHECK_TESTS_PAGE",
  [SSERV_CMD_TESTS_GENERATE_ANSWERS_PAGE] = "TESTS_GENERATE_ANSWERS_PAGE",
  [SSERV_CMD_TESTS_SOURCE_HEADER_EDIT_PAGE] = "TESTS_SOURCE_HEADER_EDIT_PAGE",
  [SSERV_CMD_TESTS_SOURCE_HEADER_EDIT_ACTION] = "TESTS_SOURCE_HEADER_EDIT_ACTION",
  [SSERV_CMD_TESTS_SOURCE_HEADER_DELETE_ACTION] = "TESTS_SOURCE_HEADER_DELETE_ACTION",
  [SSERV_CMD_TESTS_SOURCE_FOOTER_EDIT_PAGE] = "TESTS_SOURCE_FOOTER_EDIT_PAGE",
  [SSERV_CMD_TESTS_SOURCE_FOOTER_EDIT_ACTION] = "TESTS_SOURCE_FOOTER_EDIT_ACTION",
  [SSERV_CMD_TESTS_SOURCE_FOOTER_DELETE_ACTION] = "TESTS_SOURCE_FOOTER_DELETE_ACTION",
  [SSERV_CMD_TESTS_SOLUTION_EDIT_PAGE] = "TESTS_SOLUTION_EDIT_PAGE",
  [SSERV_CMD_TESTS_SOLUTION_EDIT_ACTION] = "TESTS_SOLUTION_EDIT_ACTION",
  [SSERV_CMD_TESTS_SOLUTION_DELETE_ACTION] = "TESTS_SOLUTION_DELETE_ACTION",
  [SSERV_CMD_TESTS_STYLE_CHECKER_CREATE_PAGE] = "TESTS_STYLE_CHECKER_CREATE_PAGE",
  [SSERV_CMD_TESTS_STYLE_CHECKER_CREATE_ACTION] = "TESTS_STYLE_CHECKER_CREATE_ACTION",
  [SSERV_CMD_TESTS_STYLE_CHECKER_EDIT_PAGE] = "TESTS_STYLE_CHECKER_EDIT_PAGE",
  [SSERV_CMD_TESTS_STYLE_CHECKER_EDIT_ACTION] = "TESTS_STYLE_CHECKER_EDIT_ACTION",
  [SSERV_CMD_TESTS_STYLE_CHECKER_DELETE_PAGE] = "TESTS_STYLE_CHECKER_DELETE_PAGE",
  [SSERV_CMD_TESTS_STYLE_CHECKER_DELETE_ACTION] = "TESTS_STYLE_CHECKER_DELETE_ACTION",
  [SSERV_CMD_TESTS_CHECKER_CREATE_PAGE] = "TESTS_CHECKER_CREATE_PAGE",
  [SSERV_CMD_TESTS_CHECKER_CREATE_ACTION] = "TESTS_CHECKER_CREATE_ACTION",
  [SSERV_CMD_TESTS_CHECKER_EDIT_PAGE] = "TESTS_CHECKER_EDIT_PAGE",
  [SSERV_CMD_TESTS_CHECKER_EDIT_ACTION] = "TESTS_CHECKER_EDIT_ACTION",
  [SSERV_CMD_TESTS_CHECKER_DELETE_PAGE] = "TESTS_CHECKER_DELETE_PAGE",
  [SSERV_CMD_TESTS_CHECKER_DELETE_ACTION] = "TESTS_CHECKER_DELETE_ACTION",
  [SSERV_CMD_TESTS_VALUER_CREATE_PAGE] = "TESTS_VALUER_CREATE_PAGE",
  [SSERV_CMD_TESTS_VALUER_CREATE_ACTION] = "TESTS_VALUER_CREATE_ACTION",
  [SSERV_CMD_TESTS_VALUER_EDIT_PAGE] = "TESTS_VALUER_EDIT_PAGE",
  [SSERV_CMD_TESTS_VALUER_EDIT_ACTION] = "TESTS_VALUER_EDIT_ACTION",
  [SSERV_CMD_TESTS_VALUER_DELETE_PAGE] = "TESTS_VALUER_DELETE_PAGE",
  [SSERV_CMD_TESTS_VALUER_DELETE_ACTION] = "TESTS_VALUER_DELETE_ACTION",
  [SSERV_CMD_TESTS_INTERACTOR_CREATE_PAGE] = "TESTS_INTERACTOR_CREATE_PAGE",
  [SSERV_CMD_TESTS_INTERACTOR_CREATE_ACTION] = "TESTS_INTERACTOR_CREATE_ACTION",
  [SSERV_CMD_TESTS_INTERACTOR_EDIT_PAGE] = "TESTS_INTERACTOR_EDIT_PAGE",
  [SSERV_CMD_TESTS_INTERACTOR_EDIT_ACTION] = "TESTS_INTERACTOR_EDIT_ACTION",
  [SSERV_CMD_TESTS_INTERACTOR_DELETE_PAGE] = "TESTS_INTERACTOR_DELETE_PAGE",
  [SSERV_CMD_TESTS_INTERACTOR_DELETE_ACTION] = "TESTS_INTERACTOR_DELETE_ACTION",
  [SSERV_CMD_TESTS_TEST_CHECKER_CREATE_PAGE] = "TESTS_TEST_CHECKER_CREATE_PAGE",
  [SSERV_CMD_TESTS_TEST_CHECKER_CREATE_ACTION] = "TESTS_TEST_CHECKER_CREATE_ACTION",
  [SSERV_CMD_TESTS_TEST_CHECKER_EDIT_PAGE] = "TESTS_TEST_CHECKER_EDIT_PAGE",
  [SSERV_CMD_TESTS_TEST_CHECKER_EDIT_ACTION] = "TESTS_TEST_CHECKER_EDIT_ACTION",
  [SSERV_CMD_TESTS_TEST_CHECKER_DELETE_PAGE] = "TESTS_TEST_CHECKER_DELETE_PAGE",
  [SSERV_CMD_TESTS_TEST_CHECKER_DELETE_ACTION] = "TESTS_TEST_CHECKER_DELETE_ACTION",
  [SSERV_CMD_TESTS_INIT_CREATE_PAGE] = "TESTS_INIT_CREATE_PAGE",
  [SSERV_CMD_TESTS_INIT_CREATE_ACTION] = "TESTS_INIT_CREATE_ACTION",
  [SSERV_CMD_TESTS_INIT_EDIT_PAGE] = "TESTS_INIT_EDIT_PAGE",
  [SSERV_CMD_TESTS_INIT_EDIT_ACTION] = "TESTS_INIT_EDIT_ACTION",
  [SSERV_CMD_TESTS_INIT_DELETE_PAGE] = "TESTS_INIT_DELETE_PAGE",
  [SSERV_CMD_TESTS_INIT_DELETE_ACTION] = "TESTS_INIT_DELETE_ACTION",
  [SSERV_CMD_TESTS_MAKEFILE_EDIT_PAGE] = "TESTS_MAKEFILE_EDIT_PAGE",
  [SSERV_CMD_TESTS_MAKEFILE_EDIT_ACTION] = "TESTS_MAKEFILE_EDIT_ACTION",
  [SSERV_CMD_TESTS_MAKEFILE_DELETE_ACTION] = "TESTS_MAKEFILE_DELETE_ACTION",
  [SSERV_CMD_TESTS_MAKEFILE_GENERATE_ACTION] = "TESTS_MAKEFILE_GENERATE_ACTION",
  [SSERV_CMD_TESTS_TEST_MOVE_UP_ACTION] = "TESTS_TEST_MOVE_UP_ACTION",
  [SSERV_CMD_TESTS_TEST_MOVE_DOWN_ACTION] = "TESTS_TEST_MOVE_DOWN_ACTION",
  [SSERV_CMD_TESTS_TEST_MOVE_TO_SAVED_ACTION] = "TESTS_TEST_MOVE_TO_SAVED_ACTION",
  [SSERV_CMD_TESTS_TEST_INSERT_PAGE] = "TESTS_TEST_INSERT_PAGE",
  [SSERV_CMD_TESTS_TEST_INSERT_ACTION] = "TESTS_TEST_INSERT_ACTION",
  [SSERV_CMD_TESTS_TEST_EDIT_PAGE] = "TESTS_TEST_EDIT_PAGE",
  [SSERV_CMD_TESTS_TEST_EDIT_ACTION] = "TESTS_TEST_EDIT_ACTION",
  [SSERV_CMD_TESTS_TEST_DELETE_PAGE] = "TESTS_TEST_DELETE_PAGE",
  [SSERV_CMD_TESTS_TEST_DELETE_ACTION] = "TESTS_TEST_DELETE_ACTION",
  [SSERV_CMD_TESTS_TEST_UPLOAD_ARCHIVE_1_PAGE] = "TESTS_TEST_UPLOAD_ARCHIVE_1_PAGE",
  [SSERV_CMD_TESTS_TEST_CHECK_ACTION] = "TESTS_TEST_CHECK_ACTION",
  [SSERV_CMD_TESTS_TEST_GENERATE_ACTION] = "TESTS_TEST_GENERATE_ACTION",
  [SSERV_CMD_TESTS_SAVED_MOVE_UP_ACTION] = "TESTS_SAVED_MOVE_UP_ACTION",
  [SSERV_CMD_TESTS_SAVED_MOVE_DOWN_ACTION] = "TESTS_SAVED_MOVE_DOWN_ACTION",
  [SSERV_CMD_TESTS_SAVED_DELETE_PAGE] = "TESTS_SAVED_DELETE_PAGE",
  [SSERV_CMD_TESTS_SAVED_MOVE_TO_TEST_ACTION] = "TESTS_SAVED_MOVE_TO_TEST_ACTION",
  [SSERV_CMD_TESTS_README_CREATE_PAGE] = "TESTS_README_CREATE_PAGE",
  [SSERV_CMD_TESTS_README_EDIT_PAGE] = "TESTS_README_EDIT_PAGE",
  [SSERV_CMD_TESTS_README_DELETE_PAGE] = "TESTS_README_DELETE_PAGE",
  [SSERV_CMD_TESTS_CANCEL_ACTION] = "TESTS_CANCEL_ACTION",
  [SSERV_CMD_TESTS_CANCEL_2_ACTION] = "TESTS_CANCEL_2_ACTION",
  [SSERV_CMD_TESTS_TEST_DOWNLOAD] = "TESTS_TEST_DOWNLOAD",
  [SSERV_CMD_TESTS_TEST_UPLOAD_PAGE] = "TESTS_TEST_UPLOAD_PAGE",
  [SSERV_CMD_TESTS_TEST_CLEAR_INF_ACTION] = "TESTS_TEST_CLEAR_INF_ACTION",
  [SSERV_CMD_TESTS_MAKE] = "TESTS_MAKE",
  [SSERV_CMD_USER_MAP_MAIN_PAGE] = "USER_MAP_MAIN_PAGE",
  [SSERV_CMD_USER_MAP_DELETE_ACTION] = "USER_MAP_DELETE_ACTION",
  [SSERV_CMD_USER_MAP_ADD_ACTION] = "USER_MAP_ADD_ACTION",
  [SSERV_CMD_CAPS_MAIN_PAGE] = "CAPS_MAIN_PAGE",
  [SSERV_CMD_CAPS_DELETE_ACTION] = "CAPS_DELETE_ACTION",
  [SSERV_CMD_CAPS_ADD_ACTION] = "CAPS_ADD_ACTION",
  [SSERV_CMD_CAPS_EDIT_PAGE] = "CAPS_EDIT_PAGE",
  [SSERV_CMD_CAPS_EDIT_SAVE_ACTION] = "CAPS_EDIT_SAVE_ACTION",
  [SSERV_CMD_CAPS_EDIT_CANCEL_ACTION] = "CAPS_EDIT_CANCEL_ACTION",
  [SSERV_CMD_EJUDGE_XML_UPDATE_ACTION] = "EJUDGE_XML_UPDATE_ACTION",
  [SSERV_CMD_EJUDGE_XML_CANCEL_ACTION] = "EJUDGE_XML_CANCEL_ACTION",
  [SSERV_CMD_EJUDGE_XML_MUST_RESTART] = "EJUDGE_XML_MUST_RESTART",
  [SSERV_CMD_IMPORT_FROM_POLYGON_PAGE] = "IMPORT_FROM_POLYGON_PAGE",
  [SSERV_CMD_IMPORT_FROM_POLYGON_ACTION] = "IMPORT_FROM_POLYGON_ACTION",
  [SSERV_CMD_DOWNLOAD_PROGRESS_PAGE] = "DOWNLOAD_PROGRESS_PAGE",
  [SSERV_CMD_DOWNLOAD_CLEANUP_ACTION] = "DOWNLOAD_CLEANUP_ACTION",
  [SSERV_CMD_DOWNLOAD_KILL_ACTION] = "DOWNLOAD_KILL_ACTION",
  [SSERV_CMD_DOWNLOAD_CLEANUP_AND_CHECK_ACTION] = "DOWNLOAD_CLEANUP_AND_CHECK_ACTION",
  [SSERV_CMD_DOWNLOAD_CLEANUP_AND_IMPORT_ACTION] = "DOWNLOAD_CLEANUP_AND_IMPORT_ACTION",
  [SSERV_CMD_UPDATE_FROM_POLYGON_PAGE] = "UPDATE_FROM_POLYGON_PAGE",
  [SSERV_CMD_UPDATE_FROM_POLYGON_ACTION] = "UPDATE_FROM_POLYGON_ACTION",
  [SSERV_CMD_IMPORT_PROBLEMS_BATCH_ACTION] = "IMPORT_PROBLEMS_BATCH_ACTION",
  [SSERV_CMD_CREATE_CONTEST_BATCH_ACTION] = "CREATE_CONTEST_BATCH_ACTION",
  [SSERV_CMD_IMPORT_CONTEST_FROM_POLYGON_PAGE] = "IMPORT_CONTEST_FROM_POLYGON_PAGE",
  [SSERV_CMD_LOGIN_PAGE] = "LOGIN_PAGE",
  [SSERV_CMD_MAIN_PAGE] = "MAIN_PAGE",
  [SSERV_CMD_CONTEST_PAGE] = "CONTEST_PAGE",
  [SSERV_CMD_CONTEST_XML_PAGE] = "CONTEST_XML_PAGE",
  [SSERV_CMD_SERVE_CFG_PAGE] = "SERVE_CFG_PAGE",
  [SSERV_CMD_CREATE_CONTEST_PAGE] = "CREATE_CONTEST_PAGE",
  [SSERV_CMD_CREATE_CONTEST_2_ACTION] = "CREATE_CONTEST_2_ACTION",
  [SSERV_CMD_CONTEST_ALREADY_EDITED_PAGE] = "CONTEST_ALREADY_EDITED_PAGE",
  [SSERV_CMD_CONTEST_LOCKED_PAGE] = "CONTEST_LOCKED_PAGE",
  [SSERV_CMD_CHECK_TESTS_PAGE] = "CHECK_TESTS_PAGE",
  [SSERV_CMD_CNTS_EDIT_PERMISSIONS_PAGE] = "CNTS_EDIT_PERMISSIONS_PAGE",
  [SSERV_CMD_CNTS_EDIT_REGISTER_ACCESS_PAGE] = "CNTS_EDIT_REGISTER_ACCESS_PAGE",
  [SSERV_CMD_CNTS_EDIT_USERS_ACCESS_PAGE] = "CNTS_EDIT_USERS_ACCESS_PAGE",
  [SSERV_CMD_CNTS_EDIT_MASTER_ACCESS_PAGE] = "CNTS_EDIT_MASTER_ACCESS_PAGE",
  [SSERV_CMD_CNTS_EDIT_JUDGE_ACCESS_PAGE] = "CNTS_EDIT_JUDGE_ACCESS_PAGE",
  [SSERV_CMD_CNTS_EDIT_TEAM_ACCESS_PAGE] = "CNTS_EDIT_TEAM_ACCESS_PAGE",
  [SSERV_CMD_CNTS_EDIT_SERVE_CONTROL_ACCESS_PAGE] = "CNTS_EDIT_SERVE_CONTROL_ACCESS_PAGE",
  [SSERV_CMD_CNTS_EDIT_USER_FIELDS_PAGE] = "CNTS_EDIT_USER_FIELDS_PAGE",
  [SSERV_CMD_CNTS_EDIT_CONTESTANT_FIELDS_PAGE] = "CNTS_EDIT_CONTESTANT_FIELDS_PAGE",
  [SSERV_CMD_CNTS_EDIT_RESERVE_FIELDS_PAGE] = "CNTS_EDIT_RESERVE_FIELDS_PAGE",
  [SSERV_CMD_CNTS_EDIT_COACH_FIELDS_PAGE] = "CNTS_EDIT_COACH_FIELDS_PAGE",
  [SSERV_CMD_CNTS_EDIT_ADVISOR_FIELDS_PAGE] = "CNTS_EDIT_ADVISOR_FIELDS_PAGE",
  [SSERV_CMD_CNTS_EDIT_GUEST_FIELDS_PAGE] = "CNTS_EDIT_GUEST_FIELDS_PAGE",
  [SSERV_CMD_CNTS_START_EDIT_ACTION] = "CNTS_START_EDIT_ACTION",
  [SSERV_CMD_CNTS_EDIT_CUR_CONTEST_PAGE] = "CNTS_EDIT_CUR_CONTEST_PAGE",
  [SSERV_CMD_GLOB_EDIT_CONTEST_START_CMD_PAGE] = "GLOB_EDIT_CONTEST_START_CMD_PAGE",
  [SSERV_CMD_GLOB_EDIT_CONTEST_STOP_CMD_PAGE] = "GLOB_EDIT_CONTEST_STOP_CMD_PAGE",
  [SSERV_CMD_GLOB_EDIT_STAND_HEADER_FILE_PAGE] = "GLOB_EDIT_STAND_HEADER_FILE_PAGE",
  [SSERV_CMD_GLOB_EDIT_STAND_FOOTER_FILE_PAGE] = "GLOB_EDIT_STAND_FOOTER_FILE_PAGE",
  [SSERV_CMD_GLOB_EDIT_STAND2_HEADER_FILE_PAGE] = "GLOB_EDIT_STAND2_HEADER_FILE_PAGE",
  [SSERV_CMD_GLOB_EDIT_STAND2_FOOTER_FILE_PAGE] = "GLOB_EDIT_STAND2_FOOTER_FILE_PAGE",
  [SSERV_CMD_GLOB_EDIT_PLOG_HEADER_FILE_PAGE] = "GLOB_EDIT_PLOG_HEADER_FILE_PAGE",
  [SSERV_CMD_GLOB_EDIT_PLOG_FOOTER_FILE_PAGE] = "GLOB_EDIT_PLOG_FOOTER_FILE_PAGE",
  [SSERV_CMD_CNTS_EDIT_USERS_HEADER_PAGE] = "CNTS_EDIT_USERS_HEADER_PAGE",
  [SSERV_CMD_CNTS_EDIT_USERS_FOOTER_PAGE] = "CNTS_EDIT_USERS_FOOTER_PAGE",
  [SSERV_CMD_CNTS_EDIT_COPYRIGHT_PAGE] = "CNTS_EDIT_COPYRIGHT_PAGE",
  [SSERV_CMD_CNTS_EDIT_WELCOME_PAGE] = "CNTS_EDIT_WELCOME_PAGE",
  [SSERV_CMD_CNTS_EDIT_REG_WELCOME_PAGE] = "CNTS_EDIT_REG_WELCOME_PAGE",
  [SSERV_CMD_CNTS_EDIT_REGISTER_EMAIL_FILE_PAGE] = "CNTS_EDIT_REGISTER_EMAIL_FILE_PAGE",
  [SSERV_CMD_CNTS_RELOAD_FILE_ACTION] = "CNTS_RELOAD_FILE_ACTION",
  [SSERV_CMD_CNTS_SAVE_FILE_ACTION] = "CNTS_SAVE_FILE_ACTION",
  [SSERV_CMD_CNTS_CLEAR_FILE_ACTION] = "CNTS_CLEAR_FILE_ACTION",
  [SSERV_CMD_CNTS_EDIT_CUR_GLOBAL_PAGE] = "CNTS_EDIT_CUR_GLOBAL_PAGE",
  [SSERV_CMD_CNTS_EDIT_CUR_LANGUAGE_PAGE] = "CNTS_EDIT_CUR_LANGUAGE_PAGE",
  [SSERV_CMD_CNTS_EDIT_CUR_PROBLEM_PAGE] = "CNTS_EDIT_CUR_PROBLEM_PAGE",
  [SSERV_CMD_CNTS_START_EDIT_PROBLEM_ACTION] = "CNTS_START_EDIT_PROBLEM_ACTION",
  [SSERV_CMD_CNTS_START_EDIT_VARIANT_ACTION] = "CNTS_START_EDIT_VARIANT_ACTION",
  [SSERV_CMD_CNTS_EDIT_CUR_VARIANT_PAGE] = "CNTS_EDIT_CUR_VARIANT_PAGE",
  [SSERV_CMD_CNTS_NEW_SERVE_CFG_PAGE] = "CNTS_NEW_SERVE_CFG_PAGE",
  [SSERV_CMD_CNTS_COMMIT_PAGE] = "CNTS_COMMIT_PAGE",
};
